/* Account.c generated by valac 0.56.19, the Vala compiler
 * generated from Account.vala, do not modify */

#include <glib-object.h>
#include <gtk/gtk.h>
#include <json-glib/json-glib.h>
#include <glib.h>
#include <stdlib.h>
#include <string.h>
#include <gee.h>
#include <adwaita.h>
#include <gio/gio.h>

#if !defined(VALA_STRICT_C)
#if !defined(__clang__) && defined(__GNUC__) && (__GNUC__ >= 14)
#pragma GCC diagnostic warning "-Wincompatible-pointer-types"
#elif defined(__clang__) && (__clang_major__ >= 16)
#pragma clang diagnostic ignored "-Wincompatible-function-pointer-types"
#pragma clang diagnostic ignored "-Wincompatible-pointer-types"
#endif
#endif
#if !defined(VALA_EXTERN)
#if defined(_MSC_VER)
#define VALA_EXTERN __declspec(dllexport) extern
#elif __GNUC__ >= 4
#define VALA_EXTERN __attribute__((visibility("default"))) extern
#else
#define VALA_EXTERN extern
#endif
#endif

#define TUBA_TYPE_WIDGETIZABLE (tuba_widgetizable_get_type ())
#define TUBA_WIDGETIZABLE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_TYPE_WIDGETIZABLE, TubaWidgetizable))
#define TUBA_IS_WIDGETIZABLE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_TYPE_WIDGETIZABLE))
#define TUBA_WIDGETIZABLE_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), TUBA_TYPE_WIDGETIZABLE, TubaWidgetizableIface))

typedef struct _TubaWidgetizable TubaWidgetizable;
typedef struct _TubaWidgetizableIface TubaWidgetizableIface;

#define TUBA_TYPE_ENTITY (tuba_entity_get_type ())
#define TUBA_ENTITY(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_TYPE_ENTITY, TubaEntity))
#define TUBA_ENTITY_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_TYPE_ENTITY, TubaEntityClass))
#define TUBA_IS_ENTITY(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_TYPE_ENTITY))
#define TUBA_IS_ENTITY_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_TYPE_ENTITY))
#define TUBA_ENTITY_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_TYPE_ENTITY, TubaEntityClass))

typedef struct _TubaEntity TubaEntity;
typedef struct _TubaEntityClass TubaEntityClass;

#define TUBA_API_TYPE_ACCOUNT (tuba_api_account_get_type ())
#define TUBA_API_ACCOUNT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_API_TYPE_ACCOUNT, TubaAPIAccount))
#define TUBA_API_ACCOUNT_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_API_TYPE_ACCOUNT, TubaAPIAccountClass))
#define TUBA_API_IS_ACCOUNT(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_API_TYPE_ACCOUNT))
#define TUBA_API_IS_ACCOUNT_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_API_TYPE_ACCOUNT))
#define TUBA_API_ACCOUNT_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_API_TYPE_ACCOUNT, TubaAPIAccountClass))

typedef struct _TubaAPIAccount TubaAPIAccount;
typedef struct _TubaAPIAccountClass TubaAPIAccountClass;

#define TUBA_TYPE_INSTANCE_ACCOUNT (tuba_instance_account_get_type ())
#define TUBA_INSTANCE_ACCOUNT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_TYPE_INSTANCE_ACCOUNT, TubaInstanceAccount))
#define TUBA_INSTANCE_ACCOUNT_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_TYPE_INSTANCE_ACCOUNT, TubaInstanceAccountClass))
#define TUBA_IS_INSTANCE_ACCOUNT(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_TYPE_INSTANCE_ACCOUNT))
#define TUBA_IS_INSTANCE_ACCOUNT_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_TYPE_INSTANCE_ACCOUNT))
#define TUBA_INSTANCE_ACCOUNT_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_TYPE_INSTANCE_ACCOUNT, TubaInstanceAccountClass))

typedef struct _TubaInstanceAccount TubaInstanceAccount;
typedef struct _TubaInstanceAccountClass TubaInstanceAccountClass;
typedef struct _TubaEntityPrivate TubaEntityPrivate;

#define TUBA_API_TYPE_SEARCH_RESULT (tuba_api_search_result_get_type ())
#define TUBA_API_SEARCH_RESULT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_API_TYPE_SEARCH_RESULT, TubaAPISearchResult))
#define TUBA_API_IS_SEARCH_RESULT(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_API_TYPE_SEARCH_RESULT))
#define TUBA_API_SEARCH_RESULT_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), TUBA_API_TYPE_SEARCH_RESULT, TubaAPISearchResultIface))

typedef struct _TubaAPISearchResult TubaAPISearchResult;
typedef struct _TubaAPISearchResultIface TubaAPISearchResultIface;
typedef struct _TubaAPIAccountPrivate TubaAPIAccountPrivate;

#define TUBA_API_TYPE_RELATIONSHIP (tuba_api_relationship_get_type ())
#define TUBA_API_RELATIONSHIP(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_API_TYPE_RELATIONSHIP, TubaAPIRelationship))
#define TUBA_API_RELATIONSHIP_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_API_TYPE_RELATIONSHIP, TubaAPIRelationshipClass))
#define TUBA_API_IS_RELATIONSHIP(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_API_TYPE_RELATIONSHIP))
#define TUBA_API_IS_RELATIONSHIP_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_API_TYPE_RELATIONSHIP))
#define TUBA_API_RELATIONSHIP_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_API_TYPE_RELATIONSHIP, TubaAPIRelationshipClass))

typedef struct _TubaAPIRelationship TubaAPIRelationship;
typedef struct _TubaAPIRelationshipClass TubaAPIRelationshipClass;

#define TUBA_API_TYPE_EMOJI (tuba_api_emoji_get_type ())
#define TUBA_API_EMOJI(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_API_TYPE_EMOJI, TubaAPIEmoji))
#define TUBA_API_EMOJI_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_API_TYPE_EMOJI, TubaAPIEmojiClass))
#define TUBA_API_IS_EMOJI(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_API_TYPE_EMOJI))
#define TUBA_API_IS_EMOJI_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_API_TYPE_EMOJI))
#define TUBA_API_EMOJI_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_API_TYPE_EMOJI, TubaAPIEmojiClass))

typedef struct _TubaAPIEmoji TubaAPIEmoji;
typedef struct _TubaAPIEmojiClass TubaAPIEmojiClass;

#define TUBA_API_TYPE_ACCOUNT_ROLE (tuba_api_account_role_get_type ())
#define TUBA_API_ACCOUNT_ROLE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_API_TYPE_ACCOUNT_ROLE, TubaAPIAccountRole))
#define TUBA_API_ACCOUNT_ROLE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_API_TYPE_ACCOUNT_ROLE, TubaAPIAccountRoleClass))
#define TUBA_API_IS_ACCOUNT_ROLE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_API_TYPE_ACCOUNT_ROLE))
#define TUBA_API_IS_ACCOUNT_ROLE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_API_TYPE_ACCOUNT_ROLE))
#define TUBA_API_ACCOUNT_ROLE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_API_TYPE_ACCOUNT_ROLE, TubaAPIAccountRoleClass))

typedef struct _TubaAPIAccountRole TubaAPIAccountRole;
typedef struct _TubaAPIAccountRoleClass TubaAPIAccountRoleClass;

#define TUBA_API_TYPE_ACCOUNT_FIELD (tuba_api_account_field_get_type ())
#define TUBA_API_ACCOUNT_FIELD(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_API_TYPE_ACCOUNT_FIELD, TubaAPIAccountField))
#define TUBA_API_ACCOUNT_FIELD_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_API_TYPE_ACCOUNT_FIELD, TubaAPIAccountFieldClass))
#define TUBA_API_IS_ACCOUNT_FIELD(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_API_TYPE_ACCOUNT_FIELD))
#define TUBA_API_IS_ACCOUNT_FIELD_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_API_TYPE_ACCOUNT_FIELD))
#define TUBA_API_ACCOUNT_FIELD_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_API_TYPE_ACCOUNT_FIELD, TubaAPIAccountFieldClass))

typedef struct _TubaAPIAccountField TubaAPIAccountField;
typedef struct _TubaAPIAccountFieldClass TubaAPIAccountFieldClass;

#define TUBA_API_TYPE_ACCOUNT_SOURCE (tuba_api_account_source_get_type ())
#define TUBA_API_ACCOUNT_SOURCE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_API_TYPE_ACCOUNT_SOURCE, TubaAPIAccountSource))
#define TUBA_API_ACCOUNT_SOURCE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_API_TYPE_ACCOUNT_SOURCE, TubaAPIAccountSourceClass))
#define TUBA_API_IS_ACCOUNT_SOURCE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_API_TYPE_ACCOUNT_SOURCE))
#define TUBA_API_IS_ACCOUNT_SOURCE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_API_TYPE_ACCOUNT_SOURCE))
#define TUBA_API_ACCOUNT_SOURCE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_API_TYPE_ACCOUNT_SOURCE, TubaAPIAccountSourceClass))

typedef struct _TubaAPIAccountSource TubaAPIAccountSource;
typedef struct _TubaAPIAccountSourceClass TubaAPIAccountSourceClass;

#define TUBA_API_ACCOUNT_TYPE_FEATURE_APPROVAL (tuba_api_account_feature_approval_get_type ())
#define TUBA_API_ACCOUNT_FEATURE_APPROVAL(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_API_ACCOUNT_TYPE_FEATURE_APPROVAL, TubaAPIAccountFeatureApproval))
#define TUBA_API_ACCOUNT_FEATURE_APPROVAL_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_API_ACCOUNT_TYPE_FEATURE_APPROVAL, TubaAPIAccountFeatureApprovalClass))
#define TUBA_API_ACCOUNT_IS_FEATURE_APPROVAL(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_API_ACCOUNT_TYPE_FEATURE_APPROVAL))
#define TUBA_API_ACCOUNT_IS_FEATURE_APPROVAL_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_API_ACCOUNT_TYPE_FEATURE_APPROVAL))
#define TUBA_API_ACCOUNT_FEATURE_APPROVAL_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_API_ACCOUNT_TYPE_FEATURE_APPROVAL, TubaAPIAccountFeatureApprovalClass))

typedef struct _TubaAPIAccountFeatureApproval TubaAPIAccountFeatureApproval;
typedef struct _TubaAPIAccountFeatureApprovalClass TubaAPIAccountFeatureApprovalClass;
enum  {
	TUBA_API_ACCOUNT_0_PROPERTY,
	TUBA_API_ACCOUNT_TUBA_ROW_PROPERTY,
	TUBA_API_ACCOUNT_TUBA_RS_PROPERTY,
	TUBA_API_ACCOUNT_TUBA_SEARCH_QUERY_REGEX_PROPERTY,
	TUBA_API_ACCOUNT_ID_PROPERTY,
	TUBA_API_ACCOUNT_USERNAME_PROPERTY,
	TUBA_API_ACCOUNT_ACCT_PROPERTY,
	TUBA_API_ACCOUNT_DISPLAY_NAME_PROPERTY,
	TUBA_API_ACCOUNT_NOTE_PROPERTY,
	TUBA_API_ACCOUNT_LOCKED_PROPERTY,
	TUBA_API_ACCOUNT_HEADER_PROPERTY,
	TUBA_API_ACCOUNT_HEADER_DESCRIPTION_PROPERTY,
	TUBA_API_ACCOUNT_AVATAR_PROPERTY,
	TUBA_API_ACCOUNT_AVATAR_DESCRIPTION_PROPERTY,
	TUBA_API_ACCOUNT_URL_PROPERTY,
	TUBA_API_ACCOUNT_BOT_PROPERTY,
	TUBA_API_ACCOUNT_LIMITED_PROPERTY,
	TUBA_API_ACCOUNT_SUSPENDED_PROPERTY,
	TUBA_API_ACCOUNT_MEMORIAL_PROPERTY,
	TUBA_API_ACCOUNT_SHOW_MEDIA_PROPERTY,
	TUBA_API_ACCOUNT_SHOW_MEDIA_REPLIES_PROPERTY,
	TUBA_API_ACCOUNT_SHOW_FEATURED_PROPERTY,
	TUBA_API_ACCOUNT_ENABLE_RSS_PROPERTY,
	TUBA_API_ACCOUNT_CREATED_AT_PROPERTY,
	TUBA_API_ACCOUNT_EMOJIS_PROPERTY,
	TUBA_API_ACCOUNT_FOLLOWERS_COUNT_PROPERTY,
	TUBA_API_ACCOUNT_FOLLOWING_COUNT_PROPERTY,
	TUBA_API_ACCOUNT_STATUSES_COUNT_PROPERTY,
	TUBA_API_ACCOUNT_LAST_STATUS_AT_PROPERTY,
	TUBA_API_ACCOUNT_ROLES_PROPERTY,
	TUBA_API_ACCOUNT_FIELDS_PROPERTY,
	TUBA_API_ACCOUNT_SOURCE_PROPERTY,
	TUBA_API_ACCOUNT_ROLE_PROPERTY,
	TUBA_API_ACCOUNT_MOVED_PROPERTY,
	TUBA_API_ACCOUNT_HIDE_COLLECTIONS_PROPERTY,
	TUBA_API_ACCOUNT_FEATURE_APPROVAL_PROPERTY,
	TUBA_API_ACCOUNT_HANDLE_PROPERTY,
	TUBA_API_ACCOUNT_DOMAIN_PROPERTY,
	TUBA_API_ACCOUNT_FULL_HANDLE_PROPERTY,
	TUBA_API_ACCOUNT_EMOJIS_MAP_PROPERTY,
	TUBA_API_ACCOUNT_NUM_PROPERTIES
};
static GParamSpec* tuba_api_account_properties[TUBA_API_ACCOUNT_NUM_PROPERTIES];
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))
#define _g_regex_unref0(var) ((var == NULL) ? NULL : (var = (g_regex_unref (var), NULL)))
#define _g_free0(var) (var = (g_free (var), NULL))
typedef struct _Block5Data Block5Data;

#define TUBA_TYPE_REQUEST_V2 (tuba_request_v2_get_type ())
#define TUBA_REQUEST_V2(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_TYPE_REQUEST_V2, TubaRequestV2))
#define TUBA_REQUEST_V2_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_TYPE_REQUEST_V2, TubaRequestV2Class))
#define TUBA_IS_REQUEST_V2(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_TYPE_REQUEST_V2))
#define TUBA_IS_REQUEST_V2_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_TYPE_REQUEST_V2))
#define TUBA_REQUEST_V2_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_TYPE_REQUEST_V2, TubaRequestV2Class))

typedef struct _TubaRequestV2 TubaRequestV2;
typedef struct _TubaRequestV2Class TubaRequestV2Class;
typedef enum  {
	TUBA_REQUEST_V2_METHOD_GET,
	TUBA_REQUEST_V2_METHOD_POST,
	TUBA_REQUEST_V2_METHOD_PUT,
	TUBA_REQUEST_V2_METHOD_DELETE,
	TUBA_REQUEST_V2_METHOD_PATCH
} TubaRequestV2Method;

#define TUBA_REQUEST_V2_TYPE_METHOD (tuba_request_v2_method_get_type ())

#define TUBA_TYPE_ACCOUNT_STORE (tuba_account_store_get_type ())
#define TUBA_ACCOUNT_STORE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_TYPE_ACCOUNT_STORE, TubaAccountStore))
#define TUBA_ACCOUNT_STORE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_TYPE_ACCOUNT_STORE, TubaAccountStoreClass))
#define TUBA_IS_ACCOUNT_STORE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_TYPE_ACCOUNT_STORE))
#define TUBA_IS_ACCOUNT_STORE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_TYPE_ACCOUNT_STORE))
#define TUBA_ACCOUNT_STORE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_TYPE_ACCOUNT_STORE, TubaAccountStoreClass))

typedef struct _TubaAccountStore TubaAccountStore;
typedef struct _TubaAccountStoreClass TubaAccountStoreClass;

#define TUBA_WIDGETS_TYPE_ACCOUNT_ROW (tuba_widgets_account_row_get_type ())
#define TUBA_WIDGETS_ACCOUNT_ROW(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_WIDGETS_TYPE_ACCOUNT_ROW, TubaWidgetsAccountRow))
#define TUBA_WIDGETS_ACCOUNT_ROW_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_WIDGETS_TYPE_ACCOUNT_ROW, TubaWidgetsAccountRowClass))
#define TUBA_WIDGETS_IS_ACCOUNT_ROW(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_WIDGETS_TYPE_ACCOUNT_ROW))
#define TUBA_WIDGETS_IS_ACCOUNT_ROW_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_WIDGETS_TYPE_ACCOUNT_ROW))
#define TUBA_WIDGETS_ACCOUNT_ROW_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_WIDGETS_TYPE_ACCOUNT_ROW, TubaWidgetsAccountRowClass))

typedef struct _TubaWidgetsAccountRow TubaWidgetsAccountRow;
typedef struct _TubaWidgetsAccountRowClass TubaWidgetsAccountRowClass;

#define TUBA_WIDGETS_TYPE_ACCOUNT (tuba_widgets_account_get_type ())
#define TUBA_WIDGETS_ACCOUNT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_WIDGETS_TYPE_ACCOUNT, TubaWidgetsAccount))
#define TUBA_WIDGETS_ACCOUNT_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_WIDGETS_TYPE_ACCOUNT, TubaWidgetsAccountClass))
#define TUBA_WIDGETS_IS_ACCOUNT(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_WIDGETS_TYPE_ACCOUNT))
#define TUBA_WIDGETS_IS_ACCOUNT_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_WIDGETS_TYPE_ACCOUNT))
#define TUBA_WIDGETS_ACCOUNT_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_WIDGETS_TYPE_ACCOUNT, TubaWidgetsAccountClass))

typedef struct _TubaWidgetsAccount TubaWidgetsAccount;
typedef struct _TubaWidgetsAccountClass TubaWidgetsAccountClass;

#define TUBA_VIEWS_TYPE_BASE (tuba_views_base_get_type ())
#define TUBA_VIEWS_BASE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_VIEWS_TYPE_BASE, TubaViewsBase))
#define TUBA_VIEWS_BASE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_VIEWS_TYPE_BASE, TubaViewsBaseClass))
#define TUBA_VIEWS_IS_BASE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_VIEWS_TYPE_BASE))
#define TUBA_VIEWS_IS_BASE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_VIEWS_TYPE_BASE))
#define TUBA_VIEWS_BASE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_VIEWS_TYPE_BASE, TubaViewsBaseClass))

typedef struct _TubaViewsBase TubaViewsBase;
typedef struct _TubaViewsBaseClass TubaViewsBaseClass;

#define TUBA_VIEWS_TYPE_CONTENT_BASE (tuba_views_content_base_get_type ())
#define TUBA_VIEWS_CONTENT_BASE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_VIEWS_TYPE_CONTENT_BASE, TubaViewsContentBase))
#define TUBA_VIEWS_CONTENT_BASE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_VIEWS_TYPE_CONTENT_BASE, TubaViewsContentBaseClass))
#define TUBA_VIEWS_IS_CONTENT_BASE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_VIEWS_TYPE_CONTENT_BASE))
#define TUBA_VIEWS_IS_CONTENT_BASE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_VIEWS_TYPE_CONTENT_BASE))
#define TUBA_VIEWS_CONTENT_BASE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_VIEWS_TYPE_CONTENT_BASE, TubaViewsContentBaseClass))

typedef struct _TubaViewsContentBase TubaViewsContentBase;
typedef struct _TubaViewsContentBaseClass TubaViewsContentBaseClass;

#define TUBA_VIEWS_TYPE_TIMELINE (tuba_views_timeline_get_type ())
#define TUBA_VIEWS_TIMELINE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_VIEWS_TYPE_TIMELINE, TubaViewsTimeline))
#define TUBA_VIEWS_TIMELINE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_VIEWS_TYPE_TIMELINE, TubaViewsTimelineClass))
#define TUBA_VIEWS_IS_TIMELINE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_VIEWS_TYPE_TIMELINE))
#define TUBA_VIEWS_IS_TIMELINE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_VIEWS_TYPE_TIMELINE))
#define TUBA_VIEWS_TIMELINE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_VIEWS_TYPE_TIMELINE, TubaViewsTimelineClass))

typedef struct _TubaViewsTimeline TubaViewsTimeline;
typedef struct _TubaViewsTimelineClass TubaViewsTimelineClass;

#define TUBA_VIEWS_TYPE_ACCOUNTS (tuba_views_accounts_get_type ())
#define TUBA_VIEWS_ACCOUNTS(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_VIEWS_TYPE_ACCOUNTS, TubaViewsAccounts))
#define TUBA_VIEWS_ACCOUNTS_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_VIEWS_TYPE_ACCOUNTS, TubaViewsAccountsClass))
#define TUBA_VIEWS_IS_ACCOUNTS(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_VIEWS_TYPE_ACCOUNTS))
#define TUBA_VIEWS_IS_ACCOUNTS_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_VIEWS_TYPE_ACCOUNTS))
#define TUBA_VIEWS_ACCOUNTS_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_VIEWS_TYPE_ACCOUNTS, TubaViewsAccountsClass))

typedef struct _TubaViewsAccounts TubaViewsAccounts;
typedef struct _TubaViewsAccountsClass TubaViewsAccountsClass;

#define TUBA_VIEWS_TYPE_PROFILE (tuba_views_profile_get_type ())
#define TUBA_VIEWS_PROFILE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_VIEWS_TYPE_PROFILE, TubaViewsProfile))
#define TUBA_VIEWS_PROFILE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_VIEWS_TYPE_PROFILE, TubaViewsProfileClass))
#define TUBA_VIEWS_IS_PROFILE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_VIEWS_TYPE_PROFILE))
#define TUBA_VIEWS_IS_PROFILE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_VIEWS_TYPE_PROFILE))
#define TUBA_VIEWS_PROFILE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_VIEWS_TYPE_PROFILE, TubaViewsProfileClass))

typedef struct _TubaViewsProfile TubaViewsProfile;
typedef struct _TubaViewsProfileClass TubaViewsProfileClass;

#define TUBA_TYPE_APPLICATION (tuba_application_get_type ())
#define TUBA_APPLICATION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_TYPE_APPLICATION, TubaApplication))
#define TUBA_APPLICATION_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_TYPE_APPLICATION, TubaApplicationClass))
#define TUBA_IS_APPLICATION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_TYPE_APPLICATION))
#define TUBA_IS_APPLICATION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_TYPE_APPLICATION))
#define TUBA_APPLICATION_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_TYPE_APPLICATION, TubaApplicationClass))

typedef struct _TubaApplication TubaApplication;
typedef struct _TubaApplicationClass TubaApplicationClass;

#define TUBA_DIALOGS_TYPE_MAIN_WINDOW (tuba_dialogs_main_window_get_type ())
#define TUBA_DIALOGS_MAIN_WINDOW(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_DIALOGS_TYPE_MAIN_WINDOW, TubaDialogsMainWindow))
#define TUBA_DIALOGS_MAIN_WINDOW_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_DIALOGS_TYPE_MAIN_WINDOW, TubaDialogsMainWindowClass))
#define TUBA_DIALOGS_IS_MAIN_WINDOW(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_DIALOGS_TYPE_MAIN_WINDOW))
#define TUBA_DIALOGS_IS_MAIN_WINDOW_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_DIALOGS_TYPE_MAIN_WINDOW))
#define TUBA_DIALOGS_MAIN_WINDOW_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_DIALOGS_TYPE_MAIN_WINDOW, TubaDialogsMainWindowClass))

typedef struct _TubaDialogsMainWindow TubaDialogsMainWindow;
typedef struct _TubaDialogsMainWindowClass TubaDialogsMainWindowClass;
typedef struct _Block6Data Block6Data;
#define _g_error_free0(var) ((var == NULL) ? NULL : (var = (g_error_free (var), NULL)))
#define _g_uri_unref0(var) ((var == NULL) ? NULL : (var = (g_uri_unref (var), NULL)))
typedef struct _TubaAPIAccountFeatureApprovalPrivate TubaAPIAccountFeatureApprovalPrivate;
enum  {
	TUBA_API_ACCOUNT_FEATURE_APPROVAL_0_PROPERTY,
	TUBA_API_ACCOUNT_FEATURE_APPROVAL_CURRENT_USER_PROPERTY,
	TUBA_API_ACCOUNT_FEATURE_APPROVAL_TUBA_CAN_INVITE_PROPERTY,
	TUBA_API_ACCOUNT_FEATURE_APPROVAL_NUM_PROPERTIES
};
static GParamSpec* tuba_api_account_feature_approval_properties[TUBA_API_ACCOUNT_FEATURE_APPROVAL_NUM_PROPERTIES];

struct _TubaWidgetizableIface {
	GTypeInterface parent_iface;
	GtkWidget* (*to_widget) (TubaWidgetizable* self);
	void (*open) (TubaWidgetizable* self);
	void (*resolve_open) (TubaWidgetizable* self, TubaInstanceAccount* account);
};

struct _TubaEntity {
	GObject parent_instance;
	TubaEntityPrivate * priv;
};

struct _TubaEntityClass {
	GObjectClass parent_class;
	gboolean (*is_local) (TubaEntity* self, TubaInstanceAccount* account);
	GType (*deserialize_array_type) (TubaEntity* self, const gchar* prop);
};

struct _TubaAPISearchResultIface {
	GTypeInterface parent_iface;
	GRegex* (*get_tuba_search_query_regex) (TubaAPISearchResult* self);
	void (*set_tuba_search_query_regex) (TubaAPISearchResult* self, GRegex* value);
};

struct _TubaAPIAccount {
	TubaEntity parent_instance;
	TubaAPIAccountPrivate * priv;
};

struct _TubaAPIAccountClass {
	TubaEntityClass parent_class;
};

struct _TubaAPIAccountPrivate {
	gboolean _tuba_row;
	TubaAPIRelationship* _tuba_rs;
	GRegex* _tuba_search_query_regex;
	gchar* _id;
	gchar* _username;
	gchar* _acct;
	gchar* _display_name;
	gchar* _note;
	gboolean _locked;
	gchar* _header;
	gchar* _header_description;
	gchar* _avatar;
	gchar* _avatar_description;
	gchar* _url;
	gboolean _bot;
	gboolean _limited;
	gboolean _suspended;
	gboolean _memorial;
	gboolean _show_media;
	gboolean _show_media_replies;
	gboolean _show_featured;
	gboolean _enable_rss;
	gchar* _created_at;
	GeeArrayList* _emojis;
	gint64 _followers_count;
	gint64 _following_count;
	gint64 _statuses_count;
	gchar* _last_status_at;
	GeeArrayList* _roles;
	GeeArrayList* _fields;
	TubaAPIAccountSource* _source;
	TubaAPIAccountRole* _role;
	TubaAPIAccount* _moved;
	gboolean _hide_collections;
	TubaAPIAccountFeatureApproval* _feature_approval;
};

struct _Block5Data {
	int _ref_count_;
	TubaAPIAccount* self;
	GeeHashMap* res;
};

struct _Block6Data {
	int _ref_count_;
	TubaAPIAccount* self;
	TubaInstanceAccount* account;
};

struct _TubaAPIAccountFeatureApproval {
	TubaEntity parent_instance;
	TubaAPIAccountFeatureApprovalPrivate * priv;
};

struct _TubaAPIAccountFeatureApprovalClass {
	TubaEntityClass parent_class;
};

struct _TubaAPIAccountFeatureApprovalPrivate {
	gchar* _current_user;
};

static gint TubaAPIAccount_private_offset;
static gpointer tuba_api_account_parent_class = NULL;
VALA_EXTERN TubaAccountStore* tuba_accounts;
VALA_EXTERN TubaApplication* tuba_app;
static gint TubaAPIAccountFeatureApproval_private_offset;
static gpointer tuba_api_account_feature_approval_parent_class = NULL;
static TubaWidgetizableIface * tuba_api_account_tuba_widgetizable_parent_iface = NULL;
static TubaAPISearchResultIface * tuba_api_account_tuba_api_search_result_parent_iface = NULL;

VALA_EXTERN GType tuba_entity_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaEntity, g_object_unref)
VALA_EXTERN GType tuba_api_account_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaAPIAccount, g_object_unref)
VALA_EXTERN GType tuba_instance_account_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaInstanceAccount, g_object_unref)
VALA_EXTERN GType tuba_widgetizable_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaWidgetizable, g_object_unref)
VALA_EXTERN GType tuba_api_search_result_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaAPISearchResult, g_object_unref)
VALA_EXTERN GType tuba_api_relationship_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaAPIRelationship, g_object_unref)
VALA_EXTERN GType tuba_api_emoji_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaAPIEmoji, g_object_unref)
VALA_EXTERN GType tuba_api_account_role_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaAPIAccountRole, g_object_unref)
VALA_EXTERN GType tuba_api_account_field_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaAPIAccountField, g_object_unref)
VALA_EXTERN GType tuba_api_account_source_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaAPIAccountSource, g_object_unref)
VALA_EXTERN GType tuba_api_account_feature_approval_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaAPIAccountFeatureApproval, g_object_unref)
VALA_EXTERN GType tuba_entity_deserialize_array_type (TubaEntity* self,
                                          const gchar* prop);
VALA_EXTERN gboolean tuba_entity_is_local (TubaEntity* self,
                               TubaInstanceAccount* account);
static GType tuba_api_account_real_deserialize_array_type (TubaEntity* base,
                                                    const gchar* prop);
static GeeHashMap* tuba_api_account_gen_emojis_map (TubaAPIAccount* self);
static Block5Data* block5_data_ref (Block5Data* _data5_);
static void block5_data_unref (void * _userdata_);
VALA_EXTERN GeeArrayList* tuba_api_account_get_emojis (TubaAPIAccount* self);
static gboolean ___lambda19_ (Block5Data* _data5_,
                       TubaAPIEmoji* e);
VALA_EXTERN const gchar* tuba_api_emoji_get_shortcode (TubaAPIEmoji* self);
VALA_EXTERN const gchar* tuba_api_emoji_get_url (TubaAPIEmoji* self);
static gboolean ____lambda19__gee_forall_func (gpointer g,
                                        gpointer self);
VALA_EXTERN TubaAPIAccount* tuba_api_account_from (JsonNode* node,
                                       GError** error);
VALA_EXTERN TubaEntity* tuba_entity_from_json (GType type,
                                   JsonNode* node,
                                   GError** error);
VALA_EXTERN GType tuba_request_v2_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaRequestV2, g_object_unref)
VALA_EXTERN TubaRequestV2* tuba_api_account_search (const gchar* query,
                                        GError** error);
VALA_EXTERN GType tuba_request_v2_method_get_type (void) G_GNUC_CONST ;
VALA_EXTERN GType tuba_account_store_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaAccountStore, g_object_unref)
VALA_EXTERN TubaInstanceAccount* tuba_account_store_get_active (TubaAccountStore* self);
VALA_EXTERN TubaRequestV2* tuba_request_v2_new (const gchar* url,
                                    TubaRequestV2Method method);
VALA_EXTERN TubaRequestV2* tuba_request_v2_construct (GType object_type,
                                          const gchar* url,
                                          TubaRequestV2Method method);
VALA_EXTERN void tuba_request_v2_set_account (TubaRequestV2* self,
                                  TubaInstanceAccount* value);
VALA_EXTERN void tuba_request_v2_add_parameter (TubaRequestV2* self,
                                    const gchar* key,
                                    const gchar* value);
VALA_EXTERN gboolean tuba_api_account_is_self (TubaAPIAccount* self);
VALA_EXTERN const gchar* tuba_api_account_get_id (TubaAPIAccount* self);
static gboolean tuba_api_account_real_is_local (TubaEntity* base,
                                         TubaInstanceAccount* account);
VALA_EXTERN const gchar* tuba_api_account_get_url (TubaAPIAccount* self);
VALA_EXTERN gchar* tuba_api_account_get_domain (TubaAPIAccount* self);
static GtkWidget* tuba_api_account_real_to_widget (TubaWidgetizable* base);
VALA_EXTERN gboolean tuba_api_account_get_tuba_row (TubaAPIAccount* self);
VALA_EXTERN GType tuba_widgets_account_row_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaWidgetsAccountRow, g_object_unref)
VALA_EXTERN TubaWidgetsAccountRow* tuba_widgets_account_row_new (TubaAPIAccount* account,
                                                     gboolean open_only);
VALA_EXTERN TubaWidgetsAccountRow* tuba_widgets_account_row_construct (GType object_type,
                                                           TubaAPIAccount* account,
                                                           gboolean open_only);
VALA_EXTERN void tuba_widgets_account_row_add_rs_button (TubaWidgetsAccountRow* self,
                                             gboolean from_acc);
VALA_EXTERN void tuba_widgets_account_row_enable_activation (TubaWidgetsAccountRow* self);
VALA_EXTERN void tuba_widgets_account_row_add_followers_and_verified_link (TubaWidgetsAccountRow* self);
VALA_EXTERN void tuba_widgets_account_row_add_note (TubaWidgetsAccountRow* self);
VALA_EXTERN TubaWidgetsAccount* tuba_widgets_account_new (TubaAPIAccount* account);
VALA_EXTERN TubaWidgetsAccount* tuba_widgets_account_construct (GType object_type,
                                                    TubaAPIAccount* account);
VALA_EXTERN GType tuba_widgets_account_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaWidgetsAccount, g_object_unref)
static void tuba_api_account_real_open (TubaWidgetizable* base);
VALA_EXTERN GType tuba_views_base_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaViewsBase, g_object_unref)
VALA_EXTERN GType tuba_views_content_base_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaViewsContentBase, g_object_unref)
VALA_EXTERN GType tuba_views_timeline_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaViewsTimeline, g_object_unref)
VALA_EXTERN GType tuba_views_accounts_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaViewsAccounts, g_object_unref)
VALA_EXTERN GType tuba_views_profile_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaViewsProfile, g_object_unref)
VALA_EXTERN TubaViewsProfile* tuba_views_profile_new (TubaAPIAccount* acc);
VALA_EXTERN TubaViewsProfile* tuba_views_profile_construct (GType object_type,
                                                TubaAPIAccount* acc);
VALA_EXTERN GType tuba_application_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaApplication, g_object_unref)
VALA_EXTERN GType tuba_dialogs_main_window_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaDialogsMainWindow, g_object_unref)
VALA_EXTERN TubaDialogsMainWindow* tuba_application_get_main_window (TubaApplication* self);
VALA_EXTERN TubaViewsBase* tuba_dialogs_main_window_open_view (TubaDialogsMainWindow* self,
                                                   TubaViewsBase* view);
static void tuba_api_account_real_resolve_open (TubaWidgetizable* base,
                                         TubaInstanceAccount* account);
static Block6Data* block6_data_ref (Block6Data* _data6_);
static void block6_data_unref (void * _userdata_);
VALA_EXTERN void tuba_widgetizable_open (TubaWidgetizable* self);
VALA_EXTERN void tuba_instance_account_resolve (TubaInstanceAccount* self,
                                    const gchar* url,
                                    GAsyncReadyCallback _callback_,
                                    gpointer _user_data_);
VALA_EXTERN TubaEntity* tuba_instance_account_resolve_finish (TubaInstanceAccount* self,
                                                  GAsyncResult* _res_,
                                                  GError** error);
static void ___lambda173_ (Block6Data* _data6_,
                    GObject* obj,
                    GAsyncResult* res);
VALA_EXTERN gchar* tuba_instance_account_get_handle (TubaInstanceAccount* self);
static void ____lambda173__gasync_ready_callback (GObject* source_object,
                                           GAsyncResult* res,
                                           gpointer self);
VALA_EXTERN TubaRequestV2* tuba_api_account_accept_follow_request (TubaAPIAccount* self);
VALA_EXTERN TubaRequestV2* tuba_api_account_decline_follow_request (TubaAPIAccount* self);
VALA_EXTERN TubaAPIAccount* tuba_api_account_new (void);
VALA_EXTERN TubaAPIAccount* tuba_api_account_construct (GType object_type);
VALA_EXTERN TubaEntity* tuba_entity_new (void);
VALA_EXTERN TubaEntity* tuba_entity_construct (GType object_type);
VALA_EXTERN void tuba_api_account_set_tuba_row (TubaAPIAccount* self,
                                    gboolean value);
VALA_EXTERN TubaAPIRelationship* tuba_api_account_get_tuba_rs (TubaAPIAccount* self);
VALA_EXTERN void tuba_api_account_set_tuba_rs (TubaAPIAccount* self,
                                   TubaAPIRelationship* value);
VALA_EXTERN void tuba_api_account_set_id (TubaAPIAccount* self,
                              const gchar* value);
VALA_EXTERN const gchar* tuba_api_account_get_username (TubaAPIAccount* self);
VALA_EXTERN void tuba_api_account_set_username (TubaAPIAccount* self,
                                    const gchar* value);
VALA_EXTERN const gchar* tuba_api_account_get_acct (TubaAPIAccount* self);
VALA_EXTERN void tuba_api_account_set_acct (TubaAPIAccount* self,
                                const gchar* value);
VALA_EXTERN const gchar* tuba_api_account_get_display_name (TubaAPIAccount* self);
VALA_EXTERN void tuba_api_account_set_display_name (TubaAPIAccount* self,
                                        const gchar* value);
VALA_EXTERN const gchar* tuba_api_account_get_note (TubaAPIAccount* self);
VALA_EXTERN void tuba_api_account_set_note (TubaAPIAccount* self,
                                const gchar* value);
VALA_EXTERN gboolean tuba_api_account_get_locked (TubaAPIAccount* self);
VALA_EXTERN void tuba_api_account_set_locked (TubaAPIAccount* self,
                                  gboolean value);
VALA_EXTERN const gchar* tuba_api_account_get_header (TubaAPIAccount* self);
VALA_EXTERN void tuba_api_account_set_header (TubaAPIAccount* self,
                                  const gchar* value);
VALA_EXTERN const gchar* tuba_api_account_get_header_description (TubaAPIAccount* self);
VALA_EXTERN void tuba_api_account_set_header_description (TubaAPIAccount* self,
                                              const gchar* value);
VALA_EXTERN const gchar* tuba_api_account_get_avatar (TubaAPIAccount* self);
VALA_EXTERN void tuba_api_account_set_avatar (TubaAPIAccount* self,
                                  const gchar* value);
VALA_EXTERN const gchar* tuba_api_account_get_avatar_description (TubaAPIAccount* self);
VALA_EXTERN void tuba_api_account_set_avatar_description (TubaAPIAccount* self,
                                              const gchar* value);
VALA_EXTERN void tuba_api_account_set_url (TubaAPIAccount* self,
                               const gchar* value);
VALA_EXTERN gboolean tuba_api_account_get_bot (TubaAPIAccount* self);
VALA_EXTERN void tuba_api_account_set_bot (TubaAPIAccount* self,
                               gboolean value);
VALA_EXTERN gboolean tuba_api_account_get_limited (TubaAPIAccount* self);
VALA_EXTERN void tuba_api_account_set_limited (TubaAPIAccount* self,
                                   gboolean value);
VALA_EXTERN gboolean tuba_api_account_get_suspended (TubaAPIAccount* self);
VALA_EXTERN void tuba_api_account_set_suspended (TubaAPIAccount* self,
                                     gboolean value);
VALA_EXTERN gboolean tuba_api_account_get_memorial (TubaAPIAccount* self);
VALA_EXTERN void tuba_api_account_set_memorial (TubaAPIAccount* self,
                                    gboolean value);
VALA_EXTERN gboolean tuba_api_account_get_show_media (TubaAPIAccount* self);
VALA_EXTERN void tuba_api_account_set_show_media (TubaAPIAccount* self,
                                      gboolean value);
VALA_EXTERN gboolean tuba_api_account_get_show_media_replies (TubaAPIAccount* self);
VALA_EXTERN void tuba_api_account_set_show_media_replies (TubaAPIAccount* self,
                                              gboolean value);
VALA_EXTERN gboolean tuba_api_account_get_show_featured (TubaAPIAccount* self);
VALA_EXTERN void tuba_api_account_set_show_featured (TubaAPIAccount* self,
                                         gboolean value);
VALA_EXTERN gboolean tuba_api_account_get_enable_rss (TubaAPIAccount* self);
VALA_EXTERN void tuba_api_account_set_enable_rss (TubaAPIAccount* self,
                                      gboolean value);
VALA_EXTERN const gchar* tuba_api_account_get_created_at (TubaAPIAccount* self);
VALA_EXTERN void tuba_api_account_set_created_at (TubaAPIAccount* self,
                                      const gchar* value);
VALA_EXTERN void tuba_api_account_set_emojis (TubaAPIAccount* self,
                                  GeeArrayList* value);
VALA_EXTERN gint64 tuba_api_account_get_followers_count (TubaAPIAccount* self);
VALA_EXTERN void tuba_api_account_set_followers_count (TubaAPIAccount* self,
                                           gint64 value);
VALA_EXTERN gint64 tuba_api_account_get_following_count (TubaAPIAccount* self);
VALA_EXTERN void tuba_api_account_set_following_count (TubaAPIAccount* self,
                                           gint64 value);
VALA_EXTERN gint64 tuba_api_account_get_statuses_count (TubaAPIAccount* self);
VALA_EXTERN void tuba_api_account_set_statuses_count (TubaAPIAccount* self,
                                          gint64 value);
VALA_EXTERN const gchar* tuba_api_account_get_last_status_at (TubaAPIAccount* self);
VALA_EXTERN void tuba_api_account_set_last_status_at (TubaAPIAccount* self,
                                          const gchar* value);
VALA_EXTERN GeeArrayList* tuba_api_account_get_roles (TubaAPIAccount* self);
VALA_EXTERN void tuba_api_account_set_roles (TubaAPIAccount* self,
                                 GeeArrayList* value);
VALA_EXTERN GeeArrayList* tuba_api_account_get_fields (TubaAPIAccount* self);
VALA_EXTERN void tuba_api_account_set_fields (TubaAPIAccount* self,
                                  GeeArrayList* value);
VALA_EXTERN TubaAPIAccountSource* tuba_api_account_get_source (TubaAPIAccount* self);
VALA_EXTERN void tuba_api_account_set_source (TubaAPIAccount* self,
                                  TubaAPIAccountSource* value);
VALA_EXTERN TubaAPIAccountRole* tuba_api_account_get_role (TubaAPIAccount* self);
VALA_EXTERN void tuba_api_account_set_role (TubaAPIAccount* self,
                                TubaAPIAccountRole* value);
VALA_EXTERN TubaAPIAccount* tuba_api_account_get_moved (TubaAPIAccount* self);
VALA_EXTERN void tuba_api_account_set_moved (TubaAPIAccount* self,
                                 TubaAPIAccount* value);
VALA_EXTERN gboolean tuba_api_account_get_hide_collections (TubaAPIAccount* self);
VALA_EXTERN void tuba_api_account_set_hide_collections (TubaAPIAccount* self,
                                            gboolean value);
VALA_EXTERN TubaAPIAccountFeatureApproval* tuba_api_account_get_feature_approval (TubaAPIAccount* self);
VALA_EXTERN void tuba_api_account_set_feature_approval (TubaAPIAccount* self,
                                            TubaAPIAccountFeatureApproval* value);
VALA_EXTERN gchar* tuba_api_account_get_handle (TubaAPIAccount* self);
VALA_EXTERN gchar* tuba_api_account_get_full_handle (TubaAPIAccount* self);
VALA_EXTERN GeeHashMap* tuba_api_account_get_emojis_map (TubaAPIAccount* self);
VALA_EXTERN TubaAPIAccountFeatureApproval* tuba_api_account_feature_approval_new (void);
VALA_EXTERN TubaAPIAccountFeatureApproval* tuba_api_account_feature_approval_construct (GType object_type);
VALA_EXTERN const gchar* tuba_api_account_feature_approval_get_current_user (TubaAPIAccountFeatureApproval* self);
VALA_EXTERN void tuba_api_account_feature_approval_set_current_user (TubaAPIAccountFeatureApproval* self,
                                                         const gchar* value);
VALA_EXTERN gboolean tuba_api_account_feature_approval_get_tuba_can_invite (TubaAPIAccountFeatureApproval* self);
static void tuba_api_account_feature_approval_finalize (GObject * obj);
static GType tuba_api_account_feature_approval_get_type_once (void);
static void _vala_tuba_api_account_feature_approval_get_property (GObject * object,
                                                           guint property_id,
                                                           GValue * value,
                                                           GParamSpec * pspec);
static void _vala_tuba_api_account_feature_approval_set_property (GObject * object,
                                                           guint property_id,
                                                           const GValue * value,
                                                           GParamSpec * pspec);
VALA_EXTERN GtkWidget* tuba_widgetizable_to_widget (TubaWidgetizable* self);
VALA_EXTERN void tuba_widgetizable_resolve_open (TubaWidgetizable* self,
                                     TubaInstanceAccount* account);
VALA_EXTERN GRegex* tuba_api_search_result_get_tuba_search_query_regex (TubaAPISearchResult* self);
VALA_EXTERN void tuba_api_search_result_set_tuba_search_query_regex (TubaAPISearchResult* self,
                                                         GRegex* value);
static void tuba_api_account_finalize (GObject * obj);
static GType tuba_api_account_get_type_once (void);
static void _vala_tuba_api_account_get_property (GObject * object,
                                          guint property_id,
                                          GValue * value,
                                          GParamSpec * pspec);
static void _vala_tuba_api_account_set_property (GObject * object,
                                          guint property_id,
                                          const GValue * value,
                                          GParamSpec * pspec);

static inline gpointer
tuba_api_account_get_instance_private (TubaAPIAccount* self)
{
	return G_STRUCT_MEMBER_P (self, TubaAPIAccount_private_offset);
}

static GType
tuba_api_account_real_deserialize_array_type (TubaEntity* base,
                                              const gchar* prop)
{
	TubaAPIAccount * self;
	const gchar* _tmp0_;
	GQuark _tmp2_ = 0U;
	static GQuark _tmp1_label0 = 0;
	static GQuark _tmp1_label1 = 0;
	static GQuark _tmp1_label2 = 0;
	GType result;
	self = (TubaAPIAccount*) base;
	g_return_val_if_fail (prop != NULL, G_TYPE_INVALID);
	_tmp0_ = prop;
	_tmp2_ = (NULL == _tmp0_) ? 0 : g_quark_from_string (_tmp0_);
	if (_tmp2_ == ((0 != _tmp1_label0) ? _tmp1_label0 : (_tmp1_label0 = g_quark_from_static_string ("emojis")))) {
		switch (0) {
			default:
			{
				result = TUBA_API_TYPE_EMOJI;
				return result;
			}
		}
	} else if (_tmp2_ == ((0 != _tmp1_label1) ? _tmp1_label1 : (_tmp1_label1 = g_quark_from_static_string ("fields")))) {
		switch (0) {
			default:
			{
				result = TUBA_API_TYPE_ACCOUNT_FIELD;
				return result;
			}
		}
	} else if (_tmp2_ == ((0 != _tmp1_label2) ? _tmp1_label2 : (_tmp1_label2 = g_quark_from_static_string ("roles")))) {
		switch (0) {
			default:
			{
				result = TUBA_API_TYPE_ACCOUNT_ROLE;
				return result;
			}
		}
	}
	result = TUBA_ENTITY_CLASS (tuba_api_account_parent_class)->deserialize_array_type (G_TYPE_CHECK_INSTANCE_CAST (self, TUBA_TYPE_ENTITY, TubaEntity), prop);
	return result;
}

static Block5Data*
block5_data_ref (Block5Data* _data5_)
{
	g_atomic_int_inc (&_data5_->_ref_count_);
	return _data5_;
}

static void
block5_data_unref (void * _userdata_)
{
	Block5Data* _data5_;
	_data5_ = (Block5Data*) _userdata_;
	if (g_atomic_int_dec_and_test (&_data5_->_ref_count_)) {
		TubaAPIAccount* self;
		self = _data5_->self;
		_g_object_unref0 (_data5_->res);
		_g_object_unref0 (self);
		g_slice_free (Block5Data, _data5_);
	}
}

static gboolean
___lambda19_ (Block5Data* _data5_,
              TubaAPIEmoji* e)
{
	TubaAPIAccount* self;
	GeeHashMap* _tmp0_;
	const gchar* _tmp1_;
	const gchar* _tmp2_;
	const gchar* _tmp3_;
	const gchar* _tmp4_;
	gboolean result;
	self = _data5_->self;
	g_return_val_if_fail (e != NULL, FALSE);
	_tmp0_ = _data5_->res;
	_tmp1_ = tuba_api_emoji_get_shortcode (e);
	_tmp2_ = _tmp1_;
	_tmp3_ = tuba_api_emoji_get_url (e);
	_tmp4_ = _tmp3_;
	gee_abstract_map_set ((GeeAbstractMap*) _tmp0_, _tmp2_, _tmp4_);
	result = TRUE;
	_g_object_unref0 (e);
	return result;
}

static gboolean
____lambda19__gee_forall_func (gpointer g,
                               gpointer self)
{
	gboolean result;
	result = ___lambda19_ (self, (TubaAPIEmoji*) g);
	return result;
}

static gpointer
_g_object_ref0 (gpointer self)
{
	return self ? g_object_ref (self) : NULL;
}

static GeeHashMap*
tuba_api_account_gen_emojis_map (TubaAPIAccount* self)
{
	Block5Data* _data5_;
	GeeHashMap* _tmp0_;
	gboolean _tmp1_ = FALSE;
	GeeArrayList* _tmp2_;
	GeeHashMap* _tmp7_;
	GeeHashMap* _tmp8_;
	GeeHashMap* result;
	g_return_val_if_fail (self != NULL, NULL);
	_data5_ = g_slice_new0 (Block5Data);
	_data5_->_ref_count_ = 1;
	_data5_->self = g_object_ref (self);
	_tmp0_ = gee_hash_map_new (G_TYPE_STRING, (GBoxedCopyFunc) g_strdup, (GDestroyNotify) g_free, G_TYPE_STRING, (GBoxedCopyFunc) g_strdup, (GDestroyNotify) g_free, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL);
	_data5_->res = _tmp0_;
	_tmp2_ = self->priv->_emojis;
	if (_tmp2_ != NULL) {
		GeeArrayList* _tmp3_;
		gint _tmp4_;
		gint _tmp5_;
		_tmp3_ = self->priv->_emojis;
		_tmp4_ = gee_abstract_collection_get_size ((GeeAbstractCollection*) _tmp3_);
		_tmp5_ = _tmp4_;
		_tmp1_ = _tmp5_ > 0;
	} else {
		_tmp1_ = FALSE;
	}
	if (_tmp1_) {
		GeeArrayList* _tmp6_;
		_tmp6_ = self->priv->_emojis;
		gee_abstract_collection_foreach ((GeeAbstractCollection*) _tmp6_, ____lambda19__gee_forall_func, _data5_);
	}
	_tmp7_ = _data5_->res;
	_tmp8_ = _g_object_ref0 (_tmp7_);
	result = _tmp8_;
	block5_data_unref (_data5_);
	_data5_ = NULL;
	return result;
}

TubaAPIAccount*
tuba_api_account_from (JsonNode* node,
                       GError** error)
{
	TubaEntity* _tmp0_ = NULL;
	TubaEntity* _tmp1_;
	TubaAPIAccount* _tmp2_;
	GError* _inner_error0_ = NULL;
	TubaAPIAccount* result;
	g_return_val_if_fail (node != NULL, NULL);
	_tmp1_ = tuba_entity_from_json (TUBA_API_TYPE_ACCOUNT, node, &_inner_error0_);
	_tmp0_ = _tmp1_;
	if (G_UNLIKELY (_inner_error0_ != NULL)) {
		g_propagate_error (error, _inner_error0_);
		return NULL;
	}
	_tmp2_ = _g_object_ref0 (TUBA_API_IS_ACCOUNT (_tmp0_) ? ((TubaAPIAccount*) _tmp0_) : NULL);
	result = _tmp2_;
	_g_object_unref0 (_tmp0_);
	return result;
}

TubaRequestV2*
tuba_api_account_search (const gchar* query,
                         GError** error)
{
	TubaRequestV2* req = NULL;
	TubaAccountStore* _tmp0_;
	TubaInstanceAccount* _tmp1_;
	TubaInstanceAccount* _tmp2_;
	TubaInstanceAccount* _tmp3_;
	TubaRequestV2* _tmp4_ = NULL;
	TubaRequestV2* result;
	g_return_val_if_fail (query != NULL, NULL);
	_tmp0_ = tuba_accounts;
	_tmp1_ = tuba_account_store_get_active (_tmp0_);
	_tmp2_ = _tmp1_;
	_tmp3_ = _g_object_ref0 (_tmp2_);
	_tmp4_ = tuba_request_v2_new ("/api/v1/accounts/search", TUBA_REQUEST_V2_METHOD_GET);
	tuba_request_v2_set_account (_tmp4_, _tmp3_);
	_g_object_unref0 (_tmp3_);
	req = _tmp4_;
	tuba_request_v2_add_parameter (req, "q", query);
	tuba_request_v2_add_parameter (req, "resolve", "false");
	tuba_request_v2_add_parameter (req, "limit", "4");
	result = req;
	return result;
}

gboolean
tuba_api_account_is_self (TubaAPIAccount* self)
{
	const gchar* _tmp0_;
	TubaAccountStore* _tmp1_;
	TubaInstanceAccount* _tmp2_;
	TubaInstanceAccount* _tmp3_;
	const gchar* _tmp4_;
	gboolean result;
	g_return_val_if_fail (self != NULL, FALSE);
	_tmp0_ = self->priv->_id;
	_tmp1_ = tuba_accounts;
	_tmp2_ = tuba_account_store_get_active (_tmp1_);
	_tmp3_ = _tmp2_;
	_tmp4_ = ((TubaAPIAccount*) _tmp3_)->priv->_id;
	result = g_strcmp0 (_tmp0_, _tmp4_) == 0;
	return result;
}

static gboolean
string_contains (const gchar* self,
                 const gchar* needle)
{
	gchar* _tmp0_;
	gboolean result;
	g_return_val_if_fail (self != NULL, FALSE);
	g_return_val_if_fail (needle != NULL, FALSE);
	_tmp0_ = strstr ((gchar*) self, (gchar*) needle);
	result = _tmp0_ != NULL;
	return result;
}

static gboolean
tuba_api_account_real_is_local (TubaEntity* base,
                                TubaInstanceAccount* account)
{
	TubaAPIAccount * self;
	const gchar* _tmp0_;
	gchar* _tmp1_;
	gchar* _tmp2_;
	gchar* _tmp3_;
	gboolean _tmp4_;
	gboolean result;
	self = (TubaAPIAccount*) base;
	g_return_val_if_fail (account != NULL, FALSE);
	_tmp0_ = self->priv->_url;
	_tmp1_ = tuba_api_account_get_domain ((TubaAPIAccount*) account);
	_tmp2_ = _tmp1_;
	_tmp3_ = _tmp2_;
	_tmp4_ = string_contains (_tmp0_, _tmp3_);
	_g_free0 (_tmp3_);
	result = _tmp4_;
	return result;
}

static GtkWidget*
tuba_api_account_real_to_widget (TubaWidgetizable* base)
{
	TubaAPIAccount * self;
	gboolean _tmp0_;
	TubaWidgetsAccount* _tmp6_;
	GtkWidget* result;
	self = (TubaAPIAccount*) base;
	_tmp0_ = self->priv->_tuba_row;
	if (_tmp0_) {
		TubaWidgetsAccountRow* widg = NULL;
		TubaWidgetsAccountRow* _tmp1_;
		TubaWidgetsAccountRow* _tmp2_;
		TubaWidgetsAccountRow* _tmp3_;
		TubaWidgetsAccountRow* _tmp4_;
		TubaWidgetsAccountRow* _tmp5_;
		_tmp1_ = tuba_widgets_account_row_new (self, FALSE);
		g_object_ref_sink (_tmp1_);
		widg = _tmp1_;
		_tmp2_ = widg;
		tuba_widgets_account_row_add_rs_button (_tmp2_, TRUE);
		_tmp3_ = widg;
		tuba_widgets_account_row_enable_activation (_tmp3_);
		_tmp4_ = widg;
		tuba_widgets_account_row_add_followers_and_verified_link (_tmp4_);
		_tmp5_ = widg;
		tuba_widgets_account_row_add_note (_tmp5_);
		result = (GtkWidget*) widg;
		return result;
	}
	_tmp6_ = tuba_widgets_account_new (self);
	g_object_ref_sink (_tmp6_);
	result = (GtkWidget*) _tmp6_;
	return result;
}

static void
tuba_api_account_real_open (TubaWidgetizable* base)
{
	TubaAPIAccount * self;
	TubaViewsProfile* view = NULL;
	TubaViewsProfile* _tmp0_;
	TubaApplication* _tmp1_;
	TubaDialogsMainWindow* _tmp2_;
	TubaDialogsMainWindow* _tmp3_;
	TubaViewsBase* _tmp4_;
	TubaViewsBase* _tmp5_;
	self = (TubaAPIAccount*) base;
	_tmp0_ = tuba_views_profile_new (self);
	g_object_ref_sink (_tmp0_);
	view = _tmp0_;
	_tmp1_ = tuba_app;
	_tmp2_ = tuba_application_get_main_window (_tmp1_);
	_tmp3_ = _tmp2_;
	_tmp4_ = tuba_dialogs_main_window_open_view (_tmp3_, (TubaViewsBase*) view);
	_tmp5_ = _tmp4_;
	_g_object_unref0 (_tmp5_);
	_g_object_unref0 (view);
}

static Block6Data*
block6_data_ref (Block6Data* _data6_)
{
	g_atomic_int_inc (&_data6_->_ref_count_);
	return _data6_;
}

static void
block6_data_unref (void * _userdata_)
{
	Block6Data* _data6_;
	_data6_ = (Block6Data*) _userdata_;
	if (g_atomic_int_dec_and_test (&_data6_->_ref_count_)) {
		TubaAPIAccount* self;
		self = _data6_->self;
		_g_object_unref0 (_data6_->account);
		_g_object_unref0 (self);
		g_slice_free (Block6Data, _data6_);
	}
}

static const gchar*
string_to_string (const gchar* self)
{
	const gchar* result;
	g_return_val_if_fail (self != NULL, NULL);
	result = self;
	return result;
}

static void
___lambda173_ (Block6Data* _data6_,
               GObject* obj,
               GAsyncResult* res)
{
	TubaAPIAccount* self;
	GError* _inner_error0_ = NULL;
	self = _data6_->self;
	g_return_if_fail (res != NULL);
	{
		TubaEntity* _tmp0_ = NULL;
		TubaEntity* _tmp1_;
		_tmp1_ = tuba_instance_account_resolve_finish (_data6_->account, res, &_inner_error0_);
		_tmp0_ = _tmp1_;
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
			goto __catch0_g_error;
		}
		tuba_widgetizable_open ((TubaWidgetizable*) _tmp0_);
		_g_object_unref0 (_tmp0_);
	}
	goto __finally0;
	__catch0_g_error:
	{
		GError* e = NULL;
		gchar* _tmp2_;
		gchar* _tmp3_;
		gchar* _tmp4_;
		const gchar* _tmp5_;
		GError* _tmp6_;
		const gchar* _tmp7_;
		const gchar* _tmp8_;
		gchar* _tmp9_;
		gchar* _tmp10_;
		e = _inner_error0_;
		_inner_error0_ = NULL;
		_tmp2_ = tuba_instance_account_get_handle (_data6_->account);
		_tmp3_ = _tmp2_;
		_tmp4_ = _tmp3_;
		_tmp5_ = string_to_string (_tmp4_);
		_tmp6_ = e;
		_tmp7_ = _tmp6_->message;
		_tmp8_ = string_to_string (_tmp7_);
		_tmp9_ = g_strconcat ("Error opening account: ", _tmp5_, " - ", _tmp8_, NULL);
		_tmp10_ = _tmp9_;
		g_warning ("Account.vala:173: %s", _tmp10_);
		_g_free0 (_tmp10_);
		_g_free0 (_tmp4_);
		_g_error_free0 (e);
	}
	__finally0:
	if (G_UNLIKELY (_inner_error0_ != NULL)) {
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error0_->message, g_quark_to_string (_inner_error0_->domain), _inner_error0_->code);
		g_clear_error (&_inner_error0_);
		return;
	}
}

static void
____lambda173__gasync_ready_callback (GObject* source_object,
                                      GAsyncResult* res,
                                      gpointer self)
{
	___lambda173_ (self, source_object, res);
	block6_data_unref (self);
}

static void
tuba_api_account_real_resolve_open (TubaWidgetizable* base,
                                    TubaInstanceAccount* account)
{
	TubaAPIAccount * self;
	Block6Data* _data6_;
	TubaInstanceAccount* _tmp0_;
	self = (TubaAPIAccount*) base;
	g_return_if_fail (account != NULL);
	_data6_ = g_slice_new0 (Block6Data);
	_data6_->_ref_count_ = 1;
	_data6_->self = g_object_ref (self);
	_tmp0_ = _g_object_ref0 (account);
	_g_object_unref0 (_data6_->account);
	_data6_->account = _tmp0_;
	if (tuba_entity_is_local ((TubaEntity*) self, _data6_->account)) {
		tuba_widgetizable_open ((TubaWidgetizable*) self);
	} else {
		const gchar* _tmp1_;
		_tmp1_ = self->priv->_url;
		tuba_instance_account_resolve (_data6_->account, _tmp1_, ____lambda173__gasync_ready_callback, block6_data_ref (_data6_));
	}
	block6_data_unref (_data6_);
	_data6_ = NULL;
}

TubaRequestV2*
tuba_api_account_accept_follow_request (TubaAPIAccount* self)
{
	const gchar* _tmp0_;
	const gchar* _tmp1_;
	gchar* _tmp2_;
	gchar* _tmp3_;
	TubaAccountStore* _tmp4_;
	TubaInstanceAccount* _tmp5_;
	TubaInstanceAccount* _tmp6_;
	TubaInstanceAccount* _tmp7_;
	TubaRequestV2* _tmp8_ = NULL;
	TubaRequestV2* _tmp9_;
	TubaRequestV2* result;
	g_return_val_if_fail (self != NULL, NULL);
	_tmp0_ = self->priv->_id;
	_tmp1_ = string_to_string (_tmp0_);
	_tmp2_ = g_strconcat ("/api/v1/follow_requests/", _tmp1_, "/authorize", NULL);
	_tmp3_ = _tmp2_;
	_tmp4_ = tuba_accounts;
	_tmp5_ = tuba_account_store_get_active (_tmp4_);
	_tmp6_ = _tmp5_;
	_tmp7_ = _g_object_ref0 (_tmp6_);
	_tmp8_ = tuba_request_v2_new (_tmp3_, TUBA_REQUEST_V2_METHOD_POST);
	tuba_request_v2_set_account (_tmp8_, _tmp7_);
	_g_object_unref0 (_tmp7_);
	_tmp9_ = _tmp8_;
	_g_free0 (_tmp3_);
	result = _tmp9_;
	return result;
}

TubaRequestV2*
tuba_api_account_decline_follow_request (TubaAPIAccount* self)
{
	const gchar* _tmp0_;
	const gchar* _tmp1_;
	gchar* _tmp2_;
	gchar* _tmp3_;
	TubaAccountStore* _tmp4_;
	TubaInstanceAccount* _tmp5_;
	TubaInstanceAccount* _tmp6_;
	TubaInstanceAccount* _tmp7_;
	TubaRequestV2* _tmp8_ = NULL;
	TubaRequestV2* _tmp9_;
	TubaRequestV2* result;
	g_return_val_if_fail (self != NULL, NULL);
	_tmp0_ = self->priv->_id;
	_tmp1_ = string_to_string (_tmp0_);
	_tmp2_ = g_strconcat ("/api/v1/follow_requests/", _tmp1_, "/reject", NULL);
	_tmp3_ = _tmp2_;
	_tmp4_ = tuba_accounts;
	_tmp5_ = tuba_account_store_get_active (_tmp4_);
	_tmp6_ = _tmp5_;
	_tmp7_ = _g_object_ref0 (_tmp6_);
	_tmp8_ = tuba_request_v2_new (_tmp3_, TUBA_REQUEST_V2_METHOD_POST);
	tuba_request_v2_set_account (_tmp8_, _tmp7_);
	_g_object_unref0 (_tmp7_);
	_tmp9_ = _tmp8_;
	_g_free0 (_tmp3_);
	result = _tmp9_;
	return result;
}

TubaAPIAccount*
tuba_api_account_construct (GType object_type)
{
	TubaAPIAccount * self = NULL;
	self = (TubaAPIAccount*) tuba_entity_construct (object_type);
	return self;
}

TubaAPIAccount*
tuba_api_account_new (void)
{
	return tuba_api_account_construct (TUBA_API_TYPE_ACCOUNT);
}

gboolean
tuba_api_account_get_tuba_row (TubaAPIAccount* self)
{
	gboolean result;
	g_return_val_if_fail (self != NULL, FALSE);
	result = self->priv->_tuba_row;
	return result;
}

void
tuba_api_account_set_tuba_row (TubaAPIAccount* self,
                               gboolean value)
{
	gboolean old_value;
	g_return_if_fail (self != NULL);
	old_value = tuba_api_account_get_tuba_row (self);
	if (old_value != value) {
		self->priv->_tuba_row = value;
		g_object_notify_by_pspec ((GObject *) self, tuba_api_account_properties[TUBA_API_ACCOUNT_TUBA_ROW_PROPERTY]);
	}
}

TubaAPIRelationship*
tuba_api_account_get_tuba_rs (TubaAPIAccount* self)
{
	TubaAPIRelationship* result;
	TubaAPIRelationship* _tmp0_;
	g_return_val_if_fail (self != NULL, NULL);
	_tmp0_ = self->priv->_tuba_rs;
	result = _tmp0_;
	return result;
}

void
tuba_api_account_set_tuba_rs (TubaAPIAccount* self,
                              TubaAPIRelationship* value)
{
	TubaAPIRelationship* old_value;
	g_return_if_fail (self != NULL);
	old_value = tuba_api_account_get_tuba_rs (self);
	if (old_value != value) {
		TubaAPIRelationship* _tmp0_;
		_tmp0_ = _g_object_ref0 (value);
		_g_object_unref0 (self->priv->_tuba_rs);
		self->priv->_tuba_rs = _tmp0_;
		g_object_notify_by_pspec ((GObject *) self, tuba_api_account_properties[TUBA_API_ACCOUNT_TUBA_RS_PROPERTY]);
	}
}

static GRegex*
tuba_api_account_real_get_tuba_search_query_regex (TubaAPISearchResult* base)
{
	GRegex* result;
	TubaAPIAccount* self;
	GRegex* _tmp0_;
	self = (TubaAPIAccount*) base;
	_tmp0_ = self->priv->_tuba_search_query_regex;
	result = _tmp0_;
	return result;
}

static gpointer
_g_regex_ref0 (gpointer self)
{
	return self ? g_regex_ref (self) : NULL;
}

static void
tuba_api_account_real_set_tuba_search_query_regex (TubaAPISearchResult* base,
                                                   GRegex* value)
{
	TubaAPIAccount* self;
	GRegex* old_value;
	self = (TubaAPIAccount*) base;
	old_value = tuba_api_account_real_get_tuba_search_query_regex (base);
	if (old_value != value) {
		GRegex* _tmp0_;
		_tmp0_ = _g_regex_ref0 (value);
		_g_regex_unref0 (self->priv->_tuba_search_query_regex);
		self->priv->_tuba_search_query_regex = _tmp0_;
		g_object_notify_by_pspec ((GObject *) self, tuba_api_account_properties[TUBA_API_ACCOUNT_TUBA_SEARCH_QUERY_REGEX_PROPERTY]);
	}
}

const gchar*
tuba_api_account_get_id (TubaAPIAccount* self)
{
	const gchar* result;
	const gchar* _tmp0_;
	g_return_val_if_fail (self != NULL, NULL);
	_tmp0_ = self->priv->_id;
	result = _tmp0_;
	return result;
}

void
tuba_api_account_set_id (TubaAPIAccount* self,
                         const gchar* value)
{
	gchar* old_value;
	g_return_if_fail (self != NULL);
	old_value = tuba_api_account_get_id (self);
	if (g_strcmp0 (value, old_value) != 0) {
		gchar* _tmp0_;
		_tmp0_ = g_strdup (value);
		_g_free0 (self->priv->_id);
		self->priv->_id = _tmp0_;
		g_object_notify_by_pspec ((GObject *) self, tuba_api_account_properties[TUBA_API_ACCOUNT_ID_PROPERTY]);
	}
}

const gchar*
tuba_api_account_get_username (TubaAPIAccount* self)
{
	const gchar* result;
	const gchar* _tmp0_;
	g_return_val_if_fail (self != NULL, NULL);
	_tmp0_ = self->priv->_username;
	result = _tmp0_;
	return result;
}

void
tuba_api_account_set_username (TubaAPIAccount* self,
                               const gchar* value)
{
	gchar* old_value;
	g_return_if_fail (self != NULL);
	old_value = tuba_api_account_get_username (self);
	if (g_strcmp0 (value, old_value) != 0) {
		gchar* _tmp0_;
		_tmp0_ = g_strdup (value);
		_g_free0 (self->priv->_username);
		self->priv->_username = _tmp0_;
		g_object_notify_by_pspec ((GObject *) self, tuba_api_account_properties[TUBA_API_ACCOUNT_USERNAME_PROPERTY]);
	}
}

const gchar*
tuba_api_account_get_acct (TubaAPIAccount* self)
{
	const gchar* result;
	const gchar* _tmp0_;
	g_return_val_if_fail (self != NULL, NULL);
	_tmp0_ = self->priv->_acct;
	result = _tmp0_;
	return result;
}

void
tuba_api_account_set_acct (TubaAPIAccount* self,
                           const gchar* value)
{
	gchar* old_value;
	g_return_if_fail (self != NULL);
	old_value = tuba_api_account_get_acct (self);
	if (g_strcmp0 (value, old_value) != 0) {
		gchar* _tmp0_;
		_tmp0_ = g_strdup (value);
		_g_free0 (self->priv->_acct);
		self->priv->_acct = _tmp0_;
		g_object_notify_by_pspec ((GObject *) self, tuba_api_account_properties[TUBA_API_ACCOUNT_ACCT_PROPERTY]);
	}
}

const gchar*
tuba_api_account_get_display_name (TubaAPIAccount* self)
{
	const gchar* result;
	const gchar* _tmp0_ = NULL;
	gboolean _tmp1_ = FALSE;
	const gchar* _tmp2_;
	g_return_val_if_fail (self != NULL, NULL);
	_tmp2_ = self->priv->_display_name;
	if (_tmp2_ != NULL) {
		const gchar* _tmp3_;
		gint _tmp4_;
		gint _tmp5_;
		_tmp3_ = self->priv->_display_name;
		_tmp4_ = strlen (_tmp3_);
		_tmp5_ = _tmp4_;
		_tmp1_ = _tmp5_ > 0;
	} else {
		_tmp1_ = FALSE;
	}
	if (_tmp1_) {
		const gchar* _tmp6_;
		_tmp6_ = self->priv->_display_name;
		_tmp0_ = _tmp6_;
	} else {
		const gchar* _tmp7_;
		_tmp7_ = self->priv->_username;
		_tmp0_ = _tmp7_;
	}
	result = _tmp0_;
	return result;
}

void
tuba_api_account_set_display_name (TubaAPIAccount* self,
                                   const gchar* value)
{
	gchar* _tmp0_;
	g_return_if_fail (self != NULL);
	_tmp0_ = g_strdup (value);
	_g_free0 (self->priv->_display_name);
	self->priv->_display_name = _tmp0_;
	g_object_notify_by_pspec ((GObject *) self, tuba_api_account_properties[TUBA_API_ACCOUNT_DISPLAY_NAME_PROPERTY]);
}

const gchar*
tuba_api_account_get_note (TubaAPIAccount* self)
{
	const gchar* result;
	const gchar* _tmp0_;
	g_return_val_if_fail (self != NULL, NULL);
	_tmp0_ = self->priv->_note;
	result = _tmp0_;
	return result;
}

void
tuba_api_account_set_note (TubaAPIAccount* self,
                           const gchar* value)
{
	gchar* old_value;
	g_return_if_fail (self != NULL);
	old_value = tuba_api_account_get_note (self);
	if (g_strcmp0 (value, old_value) != 0) {
		gchar* _tmp0_;
		_tmp0_ = g_strdup (value);
		_g_free0 (self->priv->_note);
		self->priv->_note = _tmp0_;
		g_object_notify_by_pspec ((GObject *) self, tuba_api_account_properties[TUBA_API_ACCOUNT_NOTE_PROPERTY]);
	}
}

gboolean
tuba_api_account_get_locked (TubaAPIAccount* self)
{
	gboolean result;
	g_return_val_if_fail (self != NULL, FALSE);
	result = self->priv->_locked;
	return result;
}

void
tuba_api_account_set_locked (TubaAPIAccount* self,
                             gboolean value)
{
	gboolean old_value;
	g_return_if_fail (self != NULL);
	old_value = tuba_api_account_get_locked (self);
	if (old_value != value) {
		self->priv->_locked = value;
		g_object_notify_by_pspec ((GObject *) self, tuba_api_account_properties[TUBA_API_ACCOUNT_LOCKED_PROPERTY]);
	}
}

const gchar*
tuba_api_account_get_header (TubaAPIAccount* self)
{
	const gchar* result;
	const gchar* _tmp0_;
	g_return_val_if_fail (self != NULL, NULL);
	_tmp0_ = self->priv->_header;
	result = _tmp0_;
	return result;
}

void
tuba_api_account_set_header (TubaAPIAccount* self,
                             const gchar* value)
{
	gchar* old_value;
	g_return_if_fail (self != NULL);
	old_value = tuba_api_account_get_header (self);
	if (g_strcmp0 (value, old_value) != 0) {
		gchar* _tmp0_;
		_tmp0_ = g_strdup (value);
		_g_free0 (self->priv->_header);
		self->priv->_header = _tmp0_;
		g_object_notify_by_pspec ((GObject *) self, tuba_api_account_properties[TUBA_API_ACCOUNT_HEADER_PROPERTY]);
	}
}

const gchar*
tuba_api_account_get_header_description (TubaAPIAccount* self)
{
	const gchar* result;
	const gchar* _tmp0_;
	g_return_val_if_fail (self != NULL, NULL);
	_tmp0_ = self->priv->_header_description;
	result = _tmp0_;
	return result;
}

void
tuba_api_account_set_header_description (TubaAPIAccount* self,
                                         const gchar* value)
{
	gchar* old_value;
	g_return_if_fail (self != NULL);
	old_value = tuba_api_account_get_header_description (self);
	if (g_strcmp0 (value, old_value) != 0) {
		gchar* _tmp0_;
		_tmp0_ = g_strdup (value);
		_g_free0 (self->priv->_header_description);
		self->priv->_header_description = _tmp0_;
		g_object_notify_by_pspec ((GObject *) self, tuba_api_account_properties[TUBA_API_ACCOUNT_HEADER_DESCRIPTION_PROPERTY]);
	}
}

const gchar*
tuba_api_account_get_avatar (TubaAPIAccount* self)
{
	const gchar* result;
	const gchar* _tmp0_;
	g_return_val_if_fail (self != NULL, NULL);
	_tmp0_ = self->priv->_avatar;
	result = _tmp0_;
	return result;
}

void
tuba_api_account_set_avatar (TubaAPIAccount* self,
                             const gchar* value)
{
	gchar* old_value;
	g_return_if_fail (self != NULL);
	old_value = tuba_api_account_get_avatar (self);
	if (g_strcmp0 (value, old_value) != 0) {
		gchar* _tmp0_;
		_tmp0_ = g_strdup (value);
		_g_free0 (self->priv->_avatar);
		self->priv->_avatar = _tmp0_;
		g_object_notify_by_pspec ((GObject *) self, tuba_api_account_properties[TUBA_API_ACCOUNT_AVATAR_PROPERTY]);
	}
}

const gchar*
tuba_api_account_get_avatar_description (TubaAPIAccount* self)
{
	const gchar* result;
	const gchar* _tmp0_;
	g_return_val_if_fail (self != NULL, NULL);
	_tmp0_ = self->priv->_avatar_description;
	result = _tmp0_;
	return result;
}

void
tuba_api_account_set_avatar_description (TubaAPIAccount* self,
                                         const gchar* value)
{
	gchar* old_value;
	g_return_if_fail (self != NULL);
	old_value = tuba_api_account_get_avatar_description (self);
	if (g_strcmp0 (value, old_value) != 0) {
		gchar* _tmp0_;
		_tmp0_ = g_strdup (value);
		_g_free0 (self->priv->_avatar_description);
		self->priv->_avatar_description = _tmp0_;
		g_object_notify_by_pspec ((GObject *) self, tuba_api_account_properties[TUBA_API_ACCOUNT_AVATAR_DESCRIPTION_PROPERTY]);
	}
}

const gchar*
tuba_api_account_get_url (TubaAPIAccount* self)
{
	const gchar* result;
	const gchar* _tmp0_;
	g_return_val_if_fail (self != NULL, NULL);
	_tmp0_ = self->priv->_url;
	result = _tmp0_;
	return result;
}

void
tuba_api_account_set_url (TubaAPIAccount* self,
                          const gchar* value)
{
	gchar* old_value;
	g_return_if_fail (self != NULL);
	old_value = tuba_api_account_get_url (self);
	if (g_strcmp0 (value, old_value) != 0) {
		gchar* _tmp0_;
		_tmp0_ = g_strdup (value);
		_g_free0 (self->priv->_url);
		self->priv->_url = _tmp0_;
		g_object_notify_by_pspec ((GObject *) self, tuba_api_account_properties[TUBA_API_ACCOUNT_URL_PROPERTY]);
	}
}

gboolean
tuba_api_account_get_bot (TubaAPIAccount* self)
{
	gboolean result;
	g_return_val_if_fail (self != NULL, FALSE);
	result = self->priv->_bot;
	return result;
}

void
tuba_api_account_set_bot (TubaAPIAccount* self,
                          gboolean value)
{
	gboolean old_value;
	g_return_if_fail (self != NULL);
	old_value = tuba_api_account_get_bot (self);
	if (old_value != value) {
		self->priv->_bot = value;
		g_object_notify_by_pspec ((GObject *) self, tuba_api_account_properties[TUBA_API_ACCOUNT_BOT_PROPERTY]);
	}
}

gboolean
tuba_api_account_get_limited (TubaAPIAccount* self)
{
	gboolean result;
	g_return_val_if_fail (self != NULL, FALSE);
	result = self->priv->_limited;
	return result;
}

void
tuba_api_account_set_limited (TubaAPIAccount* self,
                              gboolean value)
{
	gboolean old_value;
	g_return_if_fail (self != NULL);
	old_value = tuba_api_account_get_limited (self);
	if (old_value != value) {
		self->priv->_limited = value;
		g_object_notify_by_pspec ((GObject *) self, tuba_api_account_properties[TUBA_API_ACCOUNT_LIMITED_PROPERTY]);
	}
}

gboolean
tuba_api_account_get_suspended (TubaAPIAccount* self)
{
	gboolean result;
	g_return_val_if_fail (self != NULL, FALSE);
	result = self->priv->_suspended;
	return result;
}

void
tuba_api_account_set_suspended (TubaAPIAccount* self,
                                gboolean value)
{
	gboolean old_value;
	g_return_if_fail (self != NULL);
	old_value = tuba_api_account_get_suspended (self);
	if (old_value != value) {
		self->priv->_suspended = value;
		g_object_notify_by_pspec ((GObject *) self, tuba_api_account_properties[TUBA_API_ACCOUNT_SUSPENDED_PROPERTY]);
	}
}

gboolean
tuba_api_account_get_memorial (TubaAPIAccount* self)
{
	gboolean result;
	g_return_val_if_fail (self != NULL, FALSE);
	result = self->priv->_memorial;
	return result;
}

void
tuba_api_account_set_memorial (TubaAPIAccount* self,
                               gboolean value)
{
	gboolean old_value;
	g_return_if_fail (self != NULL);
	old_value = tuba_api_account_get_memorial (self);
	if (old_value != value) {
		self->priv->_memorial = value;
		g_object_notify_by_pspec ((GObject *) self, tuba_api_account_properties[TUBA_API_ACCOUNT_MEMORIAL_PROPERTY]);
	}
}

gboolean
tuba_api_account_get_show_media (TubaAPIAccount* self)
{
	gboolean result;
	g_return_val_if_fail (self != NULL, FALSE);
	result = self->priv->_show_media;
	return result;
}

void
tuba_api_account_set_show_media (TubaAPIAccount* self,
                                 gboolean value)
{
	gboolean old_value;
	g_return_if_fail (self != NULL);
	old_value = tuba_api_account_get_show_media (self);
	if (old_value != value) {
		self->priv->_show_media = value;
		g_object_notify_by_pspec ((GObject *) self, tuba_api_account_properties[TUBA_API_ACCOUNT_SHOW_MEDIA_PROPERTY]);
	}
}

gboolean
tuba_api_account_get_show_media_replies (TubaAPIAccount* self)
{
	gboolean result;
	g_return_val_if_fail (self != NULL, FALSE);
	result = self->priv->_show_media_replies;
	return result;
}

void
tuba_api_account_set_show_media_replies (TubaAPIAccount* self,
                                         gboolean value)
{
	gboolean old_value;
	g_return_if_fail (self != NULL);
	old_value = tuba_api_account_get_show_media_replies (self);
	if (old_value != value) {
		self->priv->_show_media_replies = value;
		g_object_notify_by_pspec ((GObject *) self, tuba_api_account_properties[TUBA_API_ACCOUNT_SHOW_MEDIA_REPLIES_PROPERTY]);
	}
}

gboolean
tuba_api_account_get_show_featured (TubaAPIAccount* self)
{
	gboolean result;
	g_return_val_if_fail (self != NULL, FALSE);
	result = self->priv->_show_featured;
	return result;
}

void
tuba_api_account_set_show_featured (TubaAPIAccount* self,
                                    gboolean value)
{
	gboolean old_value;
	g_return_if_fail (self != NULL);
	old_value = tuba_api_account_get_show_featured (self);
	if (old_value != value) {
		self->priv->_show_featured = value;
		g_object_notify_by_pspec ((GObject *) self, tuba_api_account_properties[TUBA_API_ACCOUNT_SHOW_FEATURED_PROPERTY]);
	}
}

gboolean
tuba_api_account_get_enable_rss (TubaAPIAccount* self)
{
	gboolean result;
	g_return_val_if_fail (self != NULL, FALSE);
	result = self->priv->_enable_rss;
	return result;
}

void
tuba_api_account_set_enable_rss (TubaAPIAccount* self,
                                 gboolean value)
{
	gboolean old_value;
	g_return_if_fail (self != NULL);
	old_value = tuba_api_account_get_enable_rss (self);
	if (old_value != value) {
		self->priv->_enable_rss = value;
		g_object_notify_by_pspec ((GObject *) self, tuba_api_account_properties[TUBA_API_ACCOUNT_ENABLE_RSS_PROPERTY]);
	}
}

const gchar*
tuba_api_account_get_created_at (TubaAPIAccount* self)
{
	const gchar* result;
	const gchar* _tmp0_;
	g_return_val_if_fail (self != NULL, NULL);
	_tmp0_ = self->priv->_created_at;
	result = _tmp0_;
	return result;
}

void
tuba_api_account_set_created_at (TubaAPIAccount* self,
                                 const gchar* value)
{
	gchar* old_value;
	g_return_if_fail (self != NULL);
	old_value = tuba_api_account_get_created_at (self);
	if (g_strcmp0 (value, old_value) != 0) {
		gchar* _tmp0_;
		_tmp0_ = g_strdup (value);
		_g_free0 (self->priv->_created_at);
		self->priv->_created_at = _tmp0_;
		g_object_notify_by_pspec ((GObject *) self, tuba_api_account_properties[TUBA_API_ACCOUNT_CREATED_AT_PROPERTY]);
	}
}

GeeArrayList*
tuba_api_account_get_emojis (TubaAPIAccount* self)
{
	GeeArrayList* result;
	GeeArrayList* _tmp0_;
	g_return_val_if_fail (self != NULL, NULL);
	_tmp0_ = self->priv->_emojis;
	result = _tmp0_;
	return result;
}

void
tuba_api_account_set_emojis (TubaAPIAccount* self,
                             GeeArrayList* value)
{
	GeeArrayList* old_value;
	g_return_if_fail (self != NULL);
	old_value = tuba_api_account_get_emojis (self);
	if (old_value != value) {
		GeeArrayList* _tmp0_;
		_tmp0_ = _g_object_ref0 (value);
		_g_object_unref0 (self->priv->_emojis);
		self->priv->_emojis = _tmp0_;
		g_object_notify_by_pspec ((GObject *) self, tuba_api_account_properties[TUBA_API_ACCOUNT_EMOJIS_PROPERTY]);
	}
}

gint64
tuba_api_account_get_followers_count (TubaAPIAccount* self)
{
	gint64 result;
	g_return_val_if_fail (self != NULL, -1LL);
	result = self->priv->_followers_count;
	return result;
}

void
tuba_api_account_set_followers_count (TubaAPIAccount* self,
                                      gint64 value)
{
	gint64 old_value;
	g_return_if_fail (self != NULL);
	old_value = tuba_api_account_get_followers_count (self);
	if (old_value != value) {
		self->priv->_followers_count = value;
		g_object_notify_by_pspec ((GObject *) self, tuba_api_account_properties[TUBA_API_ACCOUNT_FOLLOWERS_COUNT_PROPERTY]);
	}
}

gint64
tuba_api_account_get_following_count (TubaAPIAccount* self)
{
	gint64 result;
	g_return_val_if_fail (self != NULL, -1LL);
	result = self->priv->_following_count;
	return result;
}

void
tuba_api_account_set_following_count (TubaAPIAccount* self,
                                      gint64 value)
{
	gint64 old_value;
	g_return_if_fail (self != NULL);
	old_value = tuba_api_account_get_following_count (self);
	if (old_value != value) {
		self->priv->_following_count = value;
		g_object_notify_by_pspec ((GObject *) self, tuba_api_account_properties[TUBA_API_ACCOUNT_FOLLOWING_COUNT_PROPERTY]);
	}
}

gint64
tuba_api_account_get_statuses_count (TubaAPIAccount* self)
{
	gint64 result;
	g_return_val_if_fail (self != NULL, -1LL);
	result = self->priv->_statuses_count;
	return result;
}

void
tuba_api_account_set_statuses_count (TubaAPIAccount* self,
                                     gint64 value)
{
	gint64 old_value;
	g_return_if_fail (self != NULL);
	old_value = tuba_api_account_get_statuses_count (self);
	if (old_value != value) {
		self->priv->_statuses_count = value;
		g_object_notify_by_pspec ((GObject *) self, tuba_api_account_properties[TUBA_API_ACCOUNT_STATUSES_COUNT_PROPERTY]);
	}
}

const gchar*
tuba_api_account_get_last_status_at (TubaAPIAccount* self)
{
	const gchar* result;
	const gchar* _tmp0_;
	g_return_val_if_fail (self != NULL, NULL);
	_tmp0_ = self->priv->_last_status_at;
	result = _tmp0_;
	return result;
}

void
tuba_api_account_set_last_status_at (TubaAPIAccount* self,
                                     const gchar* value)
{
	gchar* old_value;
	g_return_if_fail (self != NULL);
	old_value = tuba_api_account_get_last_status_at (self);
	if (g_strcmp0 (value, old_value) != 0) {
		gchar* _tmp0_;
		_tmp0_ = g_strdup (value);
		_g_free0 (self->priv->_last_status_at);
		self->priv->_last_status_at = _tmp0_;
		g_object_notify_by_pspec ((GObject *) self, tuba_api_account_properties[TUBA_API_ACCOUNT_LAST_STATUS_AT_PROPERTY]);
	}
}

GeeArrayList*
tuba_api_account_get_roles (TubaAPIAccount* self)
{
	GeeArrayList* result;
	GeeArrayList* _tmp0_;
	g_return_val_if_fail (self != NULL, NULL);
	_tmp0_ = self->priv->_roles;
	result = _tmp0_;
	return result;
}

void
tuba_api_account_set_roles (TubaAPIAccount* self,
                            GeeArrayList* value)
{
	GeeArrayList* old_value;
	g_return_if_fail (self != NULL);
	old_value = tuba_api_account_get_roles (self);
	if (old_value != value) {
		GeeArrayList* _tmp0_;
		_tmp0_ = _g_object_ref0 (value);
		_g_object_unref0 (self->priv->_roles);
		self->priv->_roles = _tmp0_;
		g_object_notify_by_pspec ((GObject *) self, tuba_api_account_properties[TUBA_API_ACCOUNT_ROLES_PROPERTY]);
	}
}

GeeArrayList*
tuba_api_account_get_fields (TubaAPIAccount* self)
{
	GeeArrayList* result;
	GeeArrayList* _tmp0_;
	g_return_val_if_fail (self != NULL, NULL);
	_tmp0_ = self->priv->_fields;
	result = _tmp0_;
	return result;
}

void
tuba_api_account_set_fields (TubaAPIAccount* self,
                             GeeArrayList* value)
{
	GeeArrayList* old_value;
	g_return_if_fail (self != NULL);
	old_value = tuba_api_account_get_fields (self);
	if (old_value != value) {
		GeeArrayList* _tmp0_;
		_tmp0_ = _g_object_ref0 (value);
		_g_object_unref0 (self->priv->_fields);
		self->priv->_fields = _tmp0_;
		g_object_notify_by_pspec ((GObject *) self, tuba_api_account_properties[TUBA_API_ACCOUNT_FIELDS_PROPERTY]);
	}
}

TubaAPIAccountSource*
tuba_api_account_get_source (TubaAPIAccount* self)
{
	TubaAPIAccountSource* result;
	TubaAPIAccountSource* _tmp0_;
	g_return_val_if_fail (self != NULL, NULL);
	_tmp0_ = self->priv->_source;
	result = _tmp0_;
	return result;
}

void
tuba_api_account_set_source (TubaAPIAccount* self,
                             TubaAPIAccountSource* value)
{
	TubaAPIAccountSource* old_value;
	g_return_if_fail (self != NULL);
	old_value = tuba_api_account_get_source (self);
	if (old_value != value) {
		TubaAPIAccountSource* _tmp0_;
		_tmp0_ = _g_object_ref0 (value);
		_g_object_unref0 (self->priv->_source);
		self->priv->_source = _tmp0_;
		g_object_notify_by_pspec ((GObject *) self, tuba_api_account_properties[TUBA_API_ACCOUNT_SOURCE_PROPERTY]);
	}
}

TubaAPIAccountRole*
tuba_api_account_get_role (TubaAPIAccount* self)
{
	TubaAPIAccountRole* result;
	TubaAPIAccountRole* _tmp0_;
	g_return_val_if_fail (self != NULL, NULL);
	_tmp0_ = self->priv->_role;
	result = _tmp0_;
	return result;
}

void
tuba_api_account_set_role (TubaAPIAccount* self,
                           TubaAPIAccountRole* value)
{
	TubaAPIAccountRole* old_value;
	g_return_if_fail (self != NULL);
	old_value = tuba_api_account_get_role (self);
	if (old_value != value) {
		TubaAPIAccountRole* _tmp0_;
		_tmp0_ = _g_object_ref0 (value);
		_g_object_unref0 (self->priv->_role);
		self->priv->_role = _tmp0_;
		g_object_notify_by_pspec ((GObject *) self, tuba_api_account_properties[TUBA_API_ACCOUNT_ROLE_PROPERTY]);
	}
}

TubaAPIAccount*
tuba_api_account_get_moved (TubaAPIAccount* self)
{
	TubaAPIAccount* result;
	TubaAPIAccount* _tmp0_;
	g_return_val_if_fail (self != NULL, NULL);
	_tmp0_ = self->priv->_moved;
	result = _tmp0_;
	return result;
}

void
tuba_api_account_set_moved (TubaAPIAccount* self,
                            TubaAPIAccount* value)
{
	TubaAPIAccount* old_value;
	g_return_if_fail (self != NULL);
	old_value = tuba_api_account_get_moved (self);
	if (old_value != value) {
		TubaAPIAccount* _tmp0_;
		_tmp0_ = _g_object_ref0 (value);
		_g_object_unref0 (self->priv->_moved);
		self->priv->_moved = _tmp0_;
		g_object_notify_by_pspec ((GObject *) self, tuba_api_account_properties[TUBA_API_ACCOUNT_MOVED_PROPERTY]);
	}
}

gboolean
tuba_api_account_get_hide_collections (TubaAPIAccount* self)
{
	gboolean result;
	g_return_val_if_fail (self != NULL, FALSE);
	result = self->priv->_hide_collections;
	return result;
}

void
tuba_api_account_set_hide_collections (TubaAPIAccount* self,
                                       gboolean value)
{
	gboolean old_value;
	g_return_if_fail (self != NULL);
	old_value = tuba_api_account_get_hide_collections (self);
	if (old_value != value) {
		self->priv->_hide_collections = value;
		g_object_notify_by_pspec ((GObject *) self, tuba_api_account_properties[TUBA_API_ACCOUNT_HIDE_COLLECTIONS_PROPERTY]);
	}
}

TubaAPIAccountFeatureApproval*
tuba_api_account_get_feature_approval (TubaAPIAccount* self)
{
	TubaAPIAccountFeatureApproval* result;
	TubaAPIAccountFeatureApproval* _tmp0_;
	g_return_val_if_fail (self != NULL, NULL);
	_tmp0_ = self->priv->_feature_approval;
	result = _tmp0_;
	return result;
}

void
tuba_api_account_set_feature_approval (TubaAPIAccount* self,
                                       TubaAPIAccountFeatureApproval* value)
{
	TubaAPIAccountFeatureApproval* old_value;
	g_return_if_fail (self != NULL);
	old_value = tuba_api_account_get_feature_approval (self);
	if (old_value != value) {
		TubaAPIAccountFeatureApproval* _tmp0_;
		_tmp0_ = _g_object_ref0 (value);
		_g_object_unref0 (self->priv->_feature_approval);
		self->priv->_feature_approval = _tmp0_;
		g_object_notify_by_pspec ((GObject *) self, tuba_api_account_properties[TUBA_API_ACCOUNT_FEATURE_APPROVAL_PROPERTY]);
	}
}

gchar*
tuba_api_account_get_handle (TubaAPIAccount* self)
{
	gchar* result;
	const gchar* _tmp0_;
	gchar* _tmp1_;
	g_return_val_if_fail (self != NULL, NULL);
	_tmp0_ = self->priv->_acct;
	_tmp1_ = g_strconcat ("@", _tmp0_, NULL);
	result = _tmp1_;
	return result;
}

gchar*
tuba_api_account_get_domain (TubaAPIAccount* self)
{
	gchar* result;
	GUri* uri = NULL;
	GUri* _tmp7_;
	const gchar* _tmp8_;
	gchar* _tmp9_;
	GError* _inner_error0_ = NULL;
	g_return_val_if_fail (self != NULL, NULL);
	{
		GUri* _tmp0_ = NULL;
		const gchar* _tmp1_;
		GUri* _tmp2_;
		GUri* _tmp3_;
		_tmp1_ = self->priv->_url;
		_tmp2_ = g_uri_parse (_tmp1_, G_URI_FLAGS_NONE, &_inner_error0_);
		_tmp0_ = _tmp2_;
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
			if (_inner_error0_->domain == G_URI_ERROR) {
				goto __catch0_g_uri_error;
			}
			_g_uri_unref0 (uri);
			g_critical ("file %s: line %d: unexpected error: %s (%s, %d)", __FILE__, __LINE__, _inner_error0_->message, g_quark_to_string (_inner_error0_->domain), _inner_error0_->code);
			g_clear_error (&_inner_error0_);
			return NULL;
		}
		_tmp3_ = _tmp0_;
		_tmp0_ = NULL;
		_g_uri_unref0 (uri);
		uri = _tmp3_;
		_g_uri_unref0 (_tmp0_);
	}
	goto __finally0;
	__catch0_g_uri_error:
	{
		GError* e = NULL;
		GError* _tmp4_;
		const gchar* _tmp5_;
		gchar* _tmp6_;
		e = _inner_error0_;
		_inner_error0_ = NULL;
		_tmp4_ = e;
		_tmp5_ = _tmp4_->message;
		g_warning ("Account.vala:98: %s", _tmp5_);
		_tmp6_ = g_strdup ("");
		result = _tmp6_;
		_g_error_free0 (e);
		_g_uri_unref0 (uri);
		return result;
	}
	__finally0:
	if (G_UNLIKELY (_inner_error0_ != NULL)) {
		_g_uri_unref0 (uri);
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error0_->message, g_quark_to_string (_inner_error0_->domain), _inner_error0_->code);
		g_clear_error (&_inner_error0_);
		return NULL;
	}
	_tmp7_ = uri;
	_tmp8_ = g_uri_get_host (_tmp7_);
	_tmp9_ = g_strdup (_tmp8_);
	result = _tmp9_;
	_g_uri_unref0 (uri);
	return result;
}

gchar*
tuba_api_account_get_full_handle (TubaAPIAccount* self)
{
	gchar* result;
	const gchar* _tmp0_;
	const gchar* _tmp1_;
	gchar* _tmp2_;
	gchar* _tmp3_;
	gchar* _tmp4_;
	const gchar* _tmp5_;
	gchar* _tmp6_;
	gchar* _tmp7_;
	g_return_val_if_fail (self != NULL, NULL);
	_tmp0_ = self->priv->_username;
	_tmp1_ = string_to_string (_tmp0_);
	_tmp2_ = tuba_api_account_get_domain (self);
	_tmp3_ = _tmp2_;
	_tmp4_ = _tmp3_;
	_tmp5_ = string_to_string (_tmp4_);
	_tmp6_ = g_strconcat ("@", _tmp1_, "@", _tmp5_, NULL);
	_tmp7_ = _tmp6_;
	_g_free0 (_tmp4_);
	result = _tmp7_;
	return result;
}

GeeHashMap*
tuba_api_account_get_emojis_map (TubaAPIAccount* self)
{
	GeeHashMap* result;
	GeeHashMap* _tmp0_;
	g_return_val_if_fail (self != NULL, NULL);
	_tmp0_ = tuba_api_account_gen_emojis_map (self);
	result = _tmp0_;
	return result;
}

static inline gpointer
tuba_api_account_feature_approval_get_instance_private (TubaAPIAccountFeatureApproval* self)
{
	return G_STRUCT_MEMBER_P (self, TubaAPIAccountFeatureApproval_private_offset);
}

TubaAPIAccountFeatureApproval*
tuba_api_account_feature_approval_construct (GType object_type)
{
	TubaAPIAccountFeatureApproval * self = NULL;
	self = (TubaAPIAccountFeatureApproval*) tuba_entity_construct (object_type);
	return self;
}

TubaAPIAccountFeatureApproval*
tuba_api_account_feature_approval_new (void)
{
	return tuba_api_account_feature_approval_construct (TUBA_API_ACCOUNT_TYPE_FEATURE_APPROVAL);
}

const gchar*
tuba_api_account_feature_approval_get_current_user (TubaAPIAccountFeatureApproval* self)
{
	const gchar* result;
	const gchar* _tmp0_;
	g_return_val_if_fail (self != NULL, NULL);
	_tmp0_ = self->priv->_current_user;
	result = _tmp0_;
	return result;
}

void
tuba_api_account_feature_approval_set_current_user (TubaAPIAccountFeatureApproval* self,
                                                    const gchar* value)
{
	gchar* old_value;
	g_return_if_fail (self != NULL);
	old_value = tuba_api_account_feature_approval_get_current_user (self);
	if (g_strcmp0 (value, old_value) != 0) {
		gchar* _tmp0_;
		_tmp0_ = g_strdup (value);
		_g_free0 (self->priv->_current_user);
		self->priv->_current_user = _tmp0_;
		g_object_notify_by_pspec ((GObject *) self, tuba_api_account_feature_approval_properties[TUBA_API_ACCOUNT_FEATURE_APPROVAL_CURRENT_USER_PROPERTY]);
	}
}

gboolean
tuba_api_account_feature_approval_get_tuba_can_invite (TubaAPIAccountFeatureApproval* self)
{
	gboolean result;
	gboolean _tmp0_ = FALSE;
	const gchar* _tmp1_;
	g_return_val_if_fail (self != NULL, FALSE);
	_tmp1_ = self->priv->_current_user;
	if (g_strcmp0 (_tmp1_, "automatic") == 0) {
		_tmp0_ = TRUE;
	} else {
		const gchar* _tmp2_;
		_tmp2_ = self->priv->_current_user;
		_tmp0_ = g_strcmp0 (_tmp2_, "manual") == 0;
	}
	result = _tmp0_;
	return result;
}

static void
tuba_api_account_feature_approval_class_init (TubaAPIAccountFeatureApprovalClass * klass,
                                              gpointer klass_data)
{
	tuba_api_account_feature_approval_parent_class = g_type_class_peek_parent (klass);
	g_type_class_adjust_private_offset (klass, &TubaAPIAccountFeatureApproval_private_offset);
	G_OBJECT_CLASS (klass)->get_property = _vala_tuba_api_account_feature_approval_get_property;
	G_OBJECT_CLASS (klass)->set_property = _vala_tuba_api_account_feature_approval_set_property;
	G_OBJECT_CLASS (klass)->finalize = tuba_api_account_feature_approval_finalize;
	g_object_class_install_property (G_OBJECT_CLASS (klass), TUBA_API_ACCOUNT_FEATURE_APPROVAL_CURRENT_USER_PROPERTY, tuba_api_account_feature_approval_properties[TUBA_API_ACCOUNT_FEATURE_APPROVAL_CURRENT_USER_PROPERTY] = g_param_spec_string ("current-user", "current-user", "current-user", NULL, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), TUBA_API_ACCOUNT_FEATURE_APPROVAL_TUBA_CAN_INVITE_PROPERTY, tuba_api_account_feature_approval_properties[TUBA_API_ACCOUNT_FEATURE_APPROVAL_TUBA_CAN_INVITE_PROPERTY] = g_param_spec_boolean ("tuba-can-invite", "tuba-can-invite", "tuba-can-invite", FALSE, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE));
}

static void
tuba_api_account_feature_approval_instance_init (TubaAPIAccountFeatureApproval * self,
                                                 gpointer klass)
{
	self->priv = tuba_api_account_feature_approval_get_instance_private (self);
}

static void
tuba_api_account_feature_approval_finalize (GObject * obj)
{
	TubaAPIAccountFeatureApproval * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, TUBA_API_ACCOUNT_TYPE_FEATURE_APPROVAL, TubaAPIAccountFeatureApproval);
	_g_free0 (self->priv->_current_user);
	G_OBJECT_CLASS (tuba_api_account_feature_approval_parent_class)->finalize (obj);
}

 G_GNUC_NO_INLINE static GType
tuba_api_account_feature_approval_get_type_once (void)
{
	static const GTypeInfo g_define_type_info = { sizeof (TubaAPIAccountFeatureApprovalClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) tuba_api_account_feature_approval_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (TubaAPIAccountFeatureApproval), 0, (GInstanceInitFunc) tuba_api_account_feature_approval_instance_init, NULL };
	GType tuba_api_account_feature_approval_type_id;
	tuba_api_account_feature_approval_type_id = g_type_register_static (TUBA_TYPE_ENTITY, "TubaAPIAccountFeatureApproval", &g_define_type_info, G_TYPE_FLAG_NONE);
	TubaAPIAccountFeatureApproval_private_offset = g_type_add_instance_private (tuba_api_account_feature_approval_type_id, sizeof (TubaAPIAccountFeatureApprovalPrivate));
	return tuba_api_account_feature_approval_type_id;
}

GType
tuba_api_account_feature_approval_get_type (void)
{
	static GType tuba_api_account_feature_approval_type_id__once = 0;
	if (g_once_init_enter_pointer (&tuba_api_account_feature_approval_type_id__once)) {
		GType tuba_api_account_feature_approval_type_id;
		tuba_api_account_feature_approval_type_id = tuba_api_account_feature_approval_get_type_once ();
		g_once_init_leave_pointer (&tuba_api_account_feature_approval_type_id__once, tuba_api_account_feature_approval_type_id);
	}
	return tuba_api_account_feature_approval_type_id__once;
}

static void
_vala_tuba_api_account_feature_approval_get_property (GObject * object,
                                                      guint property_id,
                                                      GValue * value,
                                                      GParamSpec * pspec)
{
	TubaAPIAccountFeatureApproval * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, TUBA_API_ACCOUNT_TYPE_FEATURE_APPROVAL, TubaAPIAccountFeatureApproval);
	switch (property_id) {
		case TUBA_API_ACCOUNT_FEATURE_APPROVAL_CURRENT_USER_PROPERTY:
		g_value_set_string (value, tuba_api_account_feature_approval_get_current_user (self));
		break;
		case TUBA_API_ACCOUNT_FEATURE_APPROVAL_TUBA_CAN_INVITE_PROPERTY:
		g_value_set_boolean (value, tuba_api_account_feature_approval_get_tuba_can_invite (self));
		break;
		default:
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
		break;
	}
}

static void
_vala_tuba_api_account_feature_approval_set_property (GObject * object,
                                                      guint property_id,
                                                      const GValue * value,
                                                      GParamSpec * pspec)
{
	TubaAPIAccountFeatureApproval * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, TUBA_API_ACCOUNT_TYPE_FEATURE_APPROVAL, TubaAPIAccountFeatureApproval);
	switch (property_id) {
		case TUBA_API_ACCOUNT_FEATURE_APPROVAL_CURRENT_USER_PROPERTY:
		tuba_api_account_feature_approval_set_current_user (self, g_value_get_string (value));
		break;
		default:
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
		break;
	}
}

static void
tuba_api_account_class_init (TubaAPIAccountClass * klass,
                             gpointer klass_data)
{
	tuba_api_account_parent_class = g_type_class_peek_parent (klass);
	g_type_class_adjust_private_offset (klass, &TubaAPIAccount_private_offset);
	((TubaEntityClass *) klass)->deserialize_array_type = (GType (*) (TubaEntity*, const gchar*)) tuba_api_account_real_deserialize_array_type;
	((TubaEntityClass *) klass)->is_local = (gboolean (*) (TubaEntity*, TubaInstanceAccount*)) tuba_api_account_real_is_local;
	G_OBJECT_CLASS (klass)->get_property = _vala_tuba_api_account_get_property;
	G_OBJECT_CLASS (klass)->set_property = _vala_tuba_api_account_set_property;
	G_OBJECT_CLASS (klass)->finalize = tuba_api_account_finalize;
	g_object_class_install_property (G_OBJECT_CLASS (klass), TUBA_API_ACCOUNT_TUBA_ROW_PROPERTY, tuba_api_account_properties[TUBA_API_ACCOUNT_TUBA_ROW_PROPERTY] = g_param_spec_boolean ("tuba-row", "tuba-row", "tuba-row", FALSE, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), TUBA_API_ACCOUNT_TUBA_RS_PROPERTY, tuba_api_account_properties[TUBA_API_ACCOUNT_TUBA_RS_PROPERTY] = g_param_spec_object ("tuba-rs", "tuba-rs", "tuba-rs", TUBA_API_TYPE_RELATIONSHIP, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), TUBA_API_ACCOUNT_TUBA_SEARCH_QUERY_REGEX_PROPERTY, tuba_api_account_properties[TUBA_API_ACCOUNT_TUBA_SEARCH_QUERY_REGEX_PROPERTY] = g_param_spec_boxed ("tuba-search-query-regex", "tuba-search-query-regex", "tuba-search-query-regex", G_TYPE_REGEX, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), TUBA_API_ACCOUNT_ID_PROPERTY, tuba_api_account_properties[TUBA_API_ACCOUNT_ID_PROPERTY] = g_param_spec_string ("id", "id", "id", NULL, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), TUBA_API_ACCOUNT_USERNAME_PROPERTY, tuba_api_account_properties[TUBA_API_ACCOUNT_USERNAME_PROPERTY] = g_param_spec_string ("username", "username", "username", NULL, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), TUBA_API_ACCOUNT_ACCT_PROPERTY, tuba_api_account_properties[TUBA_API_ACCOUNT_ACCT_PROPERTY] = g_param_spec_string ("acct", "acct", "acct", NULL, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), TUBA_API_ACCOUNT_DISPLAY_NAME_PROPERTY, tuba_api_account_properties[TUBA_API_ACCOUNT_DISPLAY_NAME_PROPERTY] = g_param_spec_string ("display-name", "display-name", "display-name", NULL, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), TUBA_API_ACCOUNT_NOTE_PROPERTY, tuba_api_account_properties[TUBA_API_ACCOUNT_NOTE_PROPERTY] = g_param_spec_string ("note", "note", "note", NULL, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), TUBA_API_ACCOUNT_LOCKED_PROPERTY, tuba_api_account_properties[TUBA_API_ACCOUNT_LOCKED_PROPERTY] = g_param_spec_boolean ("locked", "locked", "locked", FALSE, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), TUBA_API_ACCOUNT_HEADER_PROPERTY, tuba_api_account_properties[TUBA_API_ACCOUNT_HEADER_PROPERTY] = g_param_spec_string ("header", "header", "header", NULL, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), TUBA_API_ACCOUNT_HEADER_DESCRIPTION_PROPERTY, tuba_api_account_properties[TUBA_API_ACCOUNT_HEADER_DESCRIPTION_PROPERTY] = g_param_spec_string ("header-description", "header-description", "header-description", NULL, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), TUBA_API_ACCOUNT_AVATAR_PROPERTY, tuba_api_account_properties[TUBA_API_ACCOUNT_AVATAR_PROPERTY] = g_param_spec_string ("avatar", "avatar", "avatar", NULL, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), TUBA_API_ACCOUNT_AVATAR_DESCRIPTION_PROPERTY, tuba_api_account_properties[TUBA_API_ACCOUNT_AVATAR_DESCRIPTION_PROPERTY] = g_param_spec_string ("avatar-description", "avatar-description", "avatar-description", NULL, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), TUBA_API_ACCOUNT_URL_PROPERTY, tuba_api_account_properties[TUBA_API_ACCOUNT_URL_PROPERTY] = g_param_spec_string ("url", "url", "url", NULL, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), TUBA_API_ACCOUNT_BOT_PROPERTY, tuba_api_account_properties[TUBA_API_ACCOUNT_BOT_PROPERTY] = g_param_spec_boolean ("bot", "bot", "bot", FALSE, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), TUBA_API_ACCOUNT_LIMITED_PROPERTY, tuba_api_account_properties[TUBA_API_ACCOUNT_LIMITED_PROPERTY] = g_param_spec_boolean ("limited", "limited", "limited", FALSE, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), TUBA_API_ACCOUNT_SUSPENDED_PROPERTY, tuba_api_account_properties[TUBA_API_ACCOUNT_SUSPENDED_PROPERTY] = g_param_spec_boolean ("suspended", "suspended", "suspended", FALSE, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), TUBA_API_ACCOUNT_MEMORIAL_PROPERTY, tuba_api_account_properties[TUBA_API_ACCOUNT_MEMORIAL_PROPERTY] = g_param_spec_boolean ("memorial", "memorial", "memorial", FALSE, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), TUBA_API_ACCOUNT_SHOW_MEDIA_PROPERTY, tuba_api_account_properties[TUBA_API_ACCOUNT_SHOW_MEDIA_PROPERTY] = g_param_spec_boolean ("show-media", "show-media", "show-media", TRUE, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), TUBA_API_ACCOUNT_SHOW_MEDIA_REPLIES_PROPERTY, tuba_api_account_properties[TUBA_API_ACCOUNT_SHOW_MEDIA_REPLIES_PROPERTY] = g_param_spec_boolean ("show-media-replies", "show-media-replies", "show-media-replies", TRUE, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), TUBA_API_ACCOUNT_SHOW_FEATURED_PROPERTY, tuba_api_account_properties[TUBA_API_ACCOUNT_SHOW_FEATURED_PROPERTY] = g_param_spec_boolean ("show-featured", "show-featured", "show-featured", TRUE, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), TUBA_API_ACCOUNT_ENABLE_RSS_PROPERTY, tuba_api_account_properties[TUBA_API_ACCOUNT_ENABLE_RSS_PROPERTY] = g_param_spec_boolean ("enable-rss", "enable-rss", "enable-rss", FALSE, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), TUBA_API_ACCOUNT_CREATED_AT_PROPERTY, tuba_api_account_properties[TUBA_API_ACCOUNT_CREATED_AT_PROPERTY] = g_param_spec_string ("created-at", "created-at", "created-at", NULL, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), TUBA_API_ACCOUNT_EMOJIS_PROPERTY, tuba_api_account_properties[TUBA_API_ACCOUNT_EMOJIS_PROPERTY] = g_param_spec_object ("emojis", "emojis", "emojis", GEE_TYPE_ARRAY_LIST, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), TUBA_API_ACCOUNT_FOLLOWERS_COUNT_PROPERTY, tuba_api_account_properties[TUBA_API_ACCOUNT_FOLLOWERS_COUNT_PROPERTY] = g_param_spec_int64 ("followers-count", "followers-count", "followers-count", G_MININT64, G_MAXINT64, 0, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), TUBA_API_ACCOUNT_FOLLOWING_COUNT_PROPERTY, tuba_api_account_properties[TUBA_API_ACCOUNT_FOLLOWING_COUNT_PROPERTY] = g_param_spec_int64 ("following-count", "following-count", "following-count", G_MININT64, G_MAXINT64, 0, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), TUBA_API_ACCOUNT_STATUSES_COUNT_PROPERTY, tuba_api_account_properties[TUBA_API_ACCOUNT_STATUSES_COUNT_PROPERTY] = g_param_spec_int64 ("statuses-count", "statuses-count", "statuses-count", G_MININT64, G_MAXINT64, 0, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), TUBA_API_ACCOUNT_LAST_STATUS_AT_PROPERTY, tuba_api_account_properties[TUBA_API_ACCOUNT_LAST_STATUS_AT_PROPERTY] = g_param_spec_string ("last-status-at", "last-status-at", "last-status-at", NULL, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), TUBA_API_ACCOUNT_ROLES_PROPERTY, tuba_api_account_properties[TUBA_API_ACCOUNT_ROLES_PROPERTY] = g_param_spec_object ("roles", "roles", "roles", GEE_TYPE_ARRAY_LIST, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), TUBA_API_ACCOUNT_FIELDS_PROPERTY, tuba_api_account_properties[TUBA_API_ACCOUNT_FIELDS_PROPERTY] = g_param_spec_object ("fields", "fields", "fields", GEE_TYPE_ARRAY_LIST, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), TUBA_API_ACCOUNT_SOURCE_PROPERTY, tuba_api_account_properties[TUBA_API_ACCOUNT_SOURCE_PROPERTY] = g_param_spec_object ("source", "source", "source", TUBA_API_TYPE_ACCOUNT_SOURCE, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), TUBA_API_ACCOUNT_ROLE_PROPERTY, tuba_api_account_properties[TUBA_API_ACCOUNT_ROLE_PROPERTY] = g_param_spec_object ("role", "role", "role", TUBA_API_TYPE_ACCOUNT_ROLE, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), TUBA_API_ACCOUNT_MOVED_PROPERTY, tuba_api_account_properties[TUBA_API_ACCOUNT_MOVED_PROPERTY] = g_param_spec_object ("moved", "moved", "moved", TUBA_API_TYPE_ACCOUNT, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), TUBA_API_ACCOUNT_HIDE_COLLECTIONS_PROPERTY, tuba_api_account_properties[TUBA_API_ACCOUNT_HIDE_COLLECTIONS_PROPERTY] = g_param_spec_boolean ("hide-collections", "hide-collections", "hide-collections", FALSE, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), TUBA_API_ACCOUNT_FEATURE_APPROVAL_PROPERTY, tuba_api_account_properties[TUBA_API_ACCOUNT_FEATURE_APPROVAL_PROPERTY] = g_param_spec_object ("feature-approval", "feature-approval", "feature-approval", TUBA_API_ACCOUNT_TYPE_FEATURE_APPROVAL, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), TUBA_API_ACCOUNT_HANDLE_PROPERTY, tuba_api_account_properties[TUBA_API_ACCOUNT_HANDLE_PROPERTY] = g_param_spec_string ("handle", "handle", "handle", NULL, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), TUBA_API_ACCOUNT_DOMAIN_PROPERTY, tuba_api_account_properties[TUBA_API_ACCOUNT_DOMAIN_PROPERTY] = g_param_spec_string ("domain", "domain", "domain", NULL, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), TUBA_API_ACCOUNT_FULL_HANDLE_PROPERTY, tuba_api_account_properties[TUBA_API_ACCOUNT_FULL_HANDLE_PROPERTY] = g_param_spec_string ("full-handle", "full-handle", "full-handle", NULL, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), TUBA_API_ACCOUNT_EMOJIS_MAP_PROPERTY, tuba_api_account_properties[TUBA_API_ACCOUNT_EMOJIS_MAP_PROPERTY] = g_param_spec_object ("emojis-map", "emojis-map", "emojis-map", GEE_TYPE_HASH_MAP, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE));
}

static void
tuba_api_account_tuba_widgetizable_interface_init (TubaWidgetizableIface * iface,
                                                   gpointer iface_data)
{
	tuba_api_account_tuba_widgetizable_parent_iface = g_type_interface_peek_parent (iface);
	iface->to_widget = (GtkWidget* (*) (TubaWidgetizable*)) tuba_api_account_real_to_widget;
	iface->open = (void (*) (TubaWidgetizable*)) tuba_api_account_real_open;
	iface->resolve_open = (void (*) (TubaWidgetizable*, TubaInstanceAccount*)) tuba_api_account_real_resolve_open;
}

static void
tuba_api_account_tuba_api_search_result_interface_init (TubaAPISearchResultIface * iface,
                                                        gpointer iface_data)
{
	tuba_api_account_tuba_api_search_result_parent_iface = g_type_interface_peek_parent (iface);
	iface->get_tuba_search_query_regex = tuba_api_account_real_get_tuba_search_query_regex;
	iface->set_tuba_search_query_regex = tuba_api_account_real_set_tuba_search_query_regex;
}

static void
tuba_api_account_instance_init (TubaAPIAccount * self,
                                gpointer klass)
{
	gchar* _tmp0_;
	gchar* _tmp1_;
	self->priv = tuba_api_account_get_instance_private (self);
	self->priv->_tuba_row = FALSE;
	self->priv->_tuba_rs = NULL;
	self->priv->_tuba_search_query_regex = NULL;
	_tmp0_ = g_strdup ("");
	self->priv->_display_name = _tmp0_;
	_tmp1_ = g_strdup ("");
	self->priv->_note = _tmp1_;
	self->priv->_header_description = NULL;
	self->priv->_avatar_description = NULL;
	self->priv->_bot = FALSE;
	self->priv->_limited = FALSE;
	self->priv->_suspended = FALSE;
	self->priv->_memorial = FALSE;
	self->priv->_show_media = TRUE;
	self->priv->_show_media_replies = TRUE;
	self->priv->_show_featured = TRUE;
	self->priv->_enable_rss = FALSE;
	self->priv->_last_status_at = NULL;
	self->priv->_roles = NULL;
	self->priv->_fields = NULL;
	self->priv->_source = NULL;
	self->priv->_role = NULL;
	self->priv->_moved = NULL;
	self->priv->_hide_collections = FALSE;
	self->priv->_feature_approval = NULL;
}

static void
tuba_api_account_finalize (GObject * obj)
{
	TubaAPIAccount * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, TUBA_API_TYPE_ACCOUNT, TubaAPIAccount);
	_g_object_unref0 (self->priv->_tuba_rs);
	_g_regex_unref0 (self->priv->_tuba_search_query_regex);
	_g_free0 (self->priv->_id);
	_g_free0 (self->priv->_username);
	_g_free0 (self->priv->_acct);
	_g_free0 (self->priv->_display_name);
	_g_free0 (self->priv->_note);
	_g_free0 (self->priv->_header);
	_g_free0 (self->priv->_header_description);
	_g_free0 (self->priv->_avatar);
	_g_free0 (self->priv->_avatar_description);
	_g_free0 (self->priv->_url);
	_g_free0 (self->priv->_created_at);
	_g_object_unref0 (self->priv->_emojis);
	_g_free0 (self->priv->_last_status_at);
	_g_object_unref0 (self->priv->_roles);
	_g_object_unref0 (self->priv->_fields);
	_g_object_unref0 (self->priv->_source);
	_g_object_unref0 (self->priv->_role);
	_g_object_unref0 (self->priv->_moved);
	_g_object_unref0 (self->priv->_feature_approval);
	G_OBJECT_CLASS (tuba_api_account_parent_class)->finalize (obj);
}

 G_GNUC_NO_INLINE static GType
tuba_api_account_get_type_once (void)
{
	static const GTypeInfo g_define_type_info = { sizeof (TubaAPIAccountClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) tuba_api_account_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (TubaAPIAccount), 0, (GInstanceInitFunc) tuba_api_account_instance_init, NULL };
	static const GInterfaceInfo tuba_widgetizable_info = { (GInterfaceInitFunc) tuba_api_account_tuba_widgetizable_interface_init, (GInterfaceFinalizeFunc) NULL, NULL};
	static const GInterfaceInfo tuba_api_search_result_info = { (GInterfaceInitFunc) tuba_api_account_tuba_api_search_result_interface_init, (GInterfaceFinalizeFunc) NULL, NULL};
	GType tuba_api_account_type_id;
	tuba_api_account_type_id = g_type_register_static (TUBA_TYPE_ENTITY, "TubaAPIAccount", &g_define_type_info, G_TYPE_FLAG_NONE);
	g_type_add_interface_static (tuba_api_account_type_id, TUBA_TYPE_WIDGETIZABLE, &tuba_widgetizable_info);
	g_type_add_interface_static (tuba_api_account_type_id, TUBA_API_TYPE_SEARCH_RESULT, &tuba_api_search_result_info);
	TubaAPIAccount_private_offset = g_type_add_instance_private (tuba_api_account_type_id, sizeof (TubaAPIAccountPrivate));
	return tuba_api_account_type_id;
}

GType
tuba_api_account_get_type (void)
{
	static GType tuba_api_account_type_id__once = 0;
	if (g_once_init_enter_pointer (&tuba_api_account_type_id__once)) {
		GType tuba_api_account_type_id;
		tuba_api_account_type_id = tuba_api_account_get_type_once ();
		g_once_init_leave_pointer (&tuba_api_account_type_id__once, tuba_api_account_type_id);
	}
	return tuba_api_account_type_id__once;
}

static void
_vala_tuba_api_account_get_property (GObject * object,
                                     guint property_id,
                                     GValue * value,
                                     GParamSpec * pspec)
{
	TubaAPIAccount * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, TUBA_API_TYPE_ACCOUNT, TubaAPIAccount);
	switch (property_id) {
		case TUBA_API_ACCOUNT_TUBA_ROW_PROPERTY:
		g_value_set_boolean (value, tuba_api_account_get_tuba_row (self));
		break;
		case TUBA_API_ACCOUNT_TUBA_RS_PROPERTY:
		g_value_set_object (value, tuba_api_account_get_tuba_rs (self));
		break;
		case TUBA_API_ACCOUNT_TUBA_SEARCH_QUERY_REGEX_PROPERTY:
		g_value_set_boxed (value, tuba_api_search_result_get_tuba_search_query_regex ((TubaAPISearchResult*) self));
		break;
		case TUBA_API_ACCOUNT_ID_PROPERTY:
		g_value_set_string (value, tuba_api_account_get_id (self));
		break;
		case TUBA_API_ACCOUNT_USERNAME_PROPERTY:
		g_value_set_string (value, tuba_api_account_get_username (self));
		break;
		case TUBA_API_ACCOUNT_ACCT_PROPERTY:
		g_value_set_string (value, tuba_api_account_get_acct (self));
		break;
		case TUBA_API_ACCOUNT_DISPLAY_NAME_PROPERTY:
		g_value_set_string (value, tuba_api_account_get_display_name (self));
		break;
		case TUBA_API_ACCOUNT_NOTE_PROPERTY:
		g_value_set_string (value, tuba_api_account_get_note (self));
		break;
		case TUBA_API_ACCOUNT_LOCKED_PROPERTY:
		g_value_set_boolean (value, tuba_api_account_get_locked (self));
		break;
		case TUBA_API_ACCOUNT_HEADER_PROPERTY:
		g_value_set_string (value, tuba_api_account_get_header (self));
		break;
		case TUBA_API_ACCOUNT_HEADER_DESCRIPTION_PROPERTY:
		g_value_set_string (value, tuba_api_account_get_header_description (self));
		break;
		case TUBA_API_ACCOUNT_AVATAR_PROPERTY:
		g_value_set_string (value, tuba_api_account_get_avatar (self));
		break;
		case TUBA_API_ACCOUNT_AVATAR_DESCRIPTION_PROPERTY:
		g_value_set_string (value, tuba_api_account_get_avatar_description (self));
		break;
		case TUBA_API_ACCOUNT_URL_PROPERTY:
		g_value_set_string (value, tuba_api_account_get_url (self));
		break;
		case TUBA_API_ACCOUNT_BOT_PROPERTY:
		g_value_set_boolean (value, tuba_api_account_get_bot (self));
		break;
		case TUBA_API_ACCOUNT_LIMITED_PROPERTY:
		g_value_set_boolean (value, tuba_api_account_get_limited (self));
		break;
		case TUBA_API_ACCOUNT_SUSPENDED_PROPERTY:
		g_value_set_boolean (value, tuba_api_account_get_suspended (self));
		break;
		case TUBA_API_ACCOUNT_MEMORIAL_PROPERTY:
		g_value_set_boolean (value, tuba_api_account_get_memorial (self));
		break;
		case TUBA_API_ACCOUNT_SHOW_MEDIA_PROPERTY:
		g_value_set_boolean (value, tuba_api_account_get_show_media (self));
		break;
		case TUBA_API_ACCOUNT_SHOW_MEDIA_REPLIES_PROPERTY:
		g_value_set_boolean (value, tuba_api_account_get_show_media_replies (self));
		break;
		case TUBA_API_ACCOUNT_SHOW_FEATURED_PROPERTY:
		g_value_set_boolean (value, tuba_api_account_get_show_featured (self));
		break;
		case TUBA_API_ACCOUNT_ENABLE_RSS_PROPERTY:
		g_value_set_boolean (value, tuba_api_account_get_enable_rss (self));
		break;
		case TUBA_API_ACCOUNT_CREATED_AT_PROPERTY:
		g_value_set_string (value, tuba_api_account_get_created_at (self));
		break;
		case TUBA_API_ACCOUNT_EMOJIS_PROPERTY:
		g_value_set_object (value, tuba_api_account_get_emojis (self));
		break;
		case TUBA_API_ACCOUNT_FOLLOWERS_COUNT_PROPERTY:
		g_value_set_int64 (value, tuba_api_account_get_followers_count (self));
		break;
		case TUBA_API_ACCOUNT_FOLLOWING_COUNT_PROPERTY:
		g_value_set_int64 (value, tuba_api_account_get_following_count (self));
		break;
		case TUBA_API_ACCOUNT_STATUSES_COUNT_PROPERTY:
		g_value_set_int64 (value, tuba_api_account_get_statuses_count (self));
		break;
		case TUBA_API_ACCOUNT_LAST_STATUS_AT_PROPERTY:
		g_value_set_string (value, tuba_api_account_get_last_status_at (self));
		break;
		case TUBA_API_ACCOUNT_ROLES_PROPERTY:
		g_value_set_object (value, tuba_api_account_get_roles (self));
		break;
		case TUBA_API_ACCOUNT_FIELDS_PROPERTY:
		g_value_set_object (value, tuba_api_account_get_fields (self));
		break;
		case TUBA_API_ACCOUNT_SOURCE_PROPERTY:
		g_value_set_object (value, tuba_api_account_get_source (self));
		break;
		case TUBA_API_ACCOUNT_ROLE_PROPERTY:
		g_value_set_object (value, tuba_api_account_get_role (self));
		break;
		case TUBA_API_ACCOUNT_MOVED_PROPERTY:
		g_value_set_object (value, tuba_api_account_get_moved (self));
		break;
		case TUBA_API_ACCOUNT_HIDE_COLLECTIONS_PROPERTY:
		g_value_set_boolean (value, tuba_api_account_get_hide_collections (self));
		break;
		case TUBA_API_ACCOUNT_FEATURE_APPROVAL_PROPERTY:
		g_value_set_object (value, tuba_api_account_get_feature_approval (self));
		break;
		case TUBA_API_ACCOUNT_HANDLE_PROPERTY:
		g_value_take_string (value, tuba_api_account_get_handle (self));
		break;
		case TUBA_API_ACCOUNT_DOMAIN_PROPERTY:
		g_value_take_string (value, tuba_api_account_get_domain (self));
		break;
		case TUBA_API_ACCOUNT_FULL_HANDLE_PROPERTY:
		g_value_take_string (value, tuba_api_account_get_full_handle (self));
		break;
		case TUBA_API_ACCOUNT_EMOJIS_MAP_PROPERTY:
		g_value_take_object (value, tuba_api_account_get_emojis_map (self));
		break;
		default:
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
		break;
	}
}

static void
_vala_tuba_api_account_set_property (GObject * object,
                                     guint property_id,
                                     const GValue * value,
                                     GParamSpec * pspec)
{
	TubaAPIAccount * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, TUBA_API_TYPE_ACCOUNT, TubaAPIAccount);
	switch (property_id) {
		case TUBA_API_ACCOUNT_TUBA_ROW_PROPERTY:
		tuba_api_account_set_tuba_row (self, g_value_get_boolean (value));
		break;
		case TUBA_API_ACCOUNT_TUBA_RS_PROPERTY:
		tuba_api_account_set_tuba_rs (self, g_value_get_object (value));
		break;
		case TUBA_API_ACCOUNT_TUBA_SEARCH_QUERY_REGEX_PROPERTY:
		tuba_api_search_result_set_tuba_search_query_regex ((TubaAPISearchResult*) self, g_value_get_boxed (value));
		break;
		case TUBA_API_ACCOUNT_ID_PROPERTY:
		tuba_api_account_set_id (self, g_value_get_string (value));
		break;
		case TUBA_API_ACCOUNT_USERNAME_PROPERTY:
		tuba_api_account_set_username (self, g_value_get_string (value));
		break;
		case TUBA_API_ACCOUNT_ACCT_PROPERTY:
		tuba_api_account_set_acct (self, g_value_get_string (value));
		break;
		case TUBA_API_ACCOUNT_DISPLAY_NAME_PROPERTY:
		tuba_api_account_set_display_name (self, g_value_get_string (value));
		break;
		case TUBA_API_ACCOUNT_NOTE_PROPERTY:
		tuba_api_account_set_note (self, g_value_get_string (value));
		break;
		case TUBA_API_ACCOUNT_LOCKED_PROPERTY:
		tuba_api_account_set_locked (self, g_value_get_boolean (value));
		break;
		case TUBA_API_ACCOUNT_HEADER_PROPERTY:
		tuba_api_account_set_header (self, g_value_get_string (value));
		break;
		case TUBA_API_ACCOUNT_HEADER_DESCRIPTION_PROPERTY:
		tuba_api_account_set_header_description (self, g_value_get_string (value));
		break;
		case TUBA_API_ACCOUNT_AVATAR_PROPERTY:
		tuba_api_account_set_avatar (self, g_value_get_string (value));
		break;
		case TUBA_API_ACCOUNT_AVATAR_DESCRIPTION_PROPERTY:
		tuba_api_account_set_avatar_description (self, g_value_get_string (value));
		break;
		case TUBA_API_ACCOUNT_URL_PROPERTY:
		tuba_api_account_set_url (self, g_value_get_string (value));
		break;
		case TUBA_API_ACCOUNT_BOT_PROPERTY:
		tuba_api_account_set_bot (self, g_value_get_boolean (value));
		break;
		case TUBA_API_ACCOUNT_LIMITED_PROPERTY:
		tuba_api_account_set_limited (self, g_value_get_boolean (value));
		break;
		case TUBA_API_ACCOUNT_SUSPENDED_PROPERTY:
		tuba_api_account_set_suspended (self, g_value_get_boolean (value));
		break;
		case TUBA_API_ACCOUNT_MEMORIAL_PROPERTY:
		tuba_api_account_set_memorial (self, g_value_get_boolean (value));
		break;
		case TUBA_API_ACCOUNT_SHOW_MEDIA_PROPERTY:
		tuba_api_account_set_show_media (self, g_value_get_boolean (value));
		break;
		case TUBA_API_ACCOUNT_SHOW_MEDIA_REPLIES_PROPERTY:
		tuba_api_account_set_show_media_replies (self, g_value_get_boolean (value));
		break;
		case TUBA_API_ACCOUNT_SHOW_FEATURED_PROPERTY:
		tuba_api_account_set_show_featured (self, g_value_get_boolean (value));
		break;
		case TUBA_API_ACCOUNT_ENABLE_RSS_PROPERTY:
		tuba_api_account_set_enable_rss (self, g_value_get_boolean (value));
		break;
		case TUBA_API_ACCOUNT_CREATED_AT_PROPERTY:
		tuba_api_account_set_created_at (self, g_value_get_string (value));
		break;
		case TUBA_API_ACCOUNT_EMOJIS_PROPERTY:
		tuba_api_account_set_emojis (self, g_value_get_object (value));
		break;
		case TUBA_API_ACCOUNT_FOLLOWERS_COUNT_PROPERTY:
		tuba_api_account_set_followers_count (self, g_value_get_int64 (value));
		break;
		case TUBA_API_ACCOUNT_FOLLOWING_COUNT_PROPERTY:
		tuba_api_account_set_following_count (self, g_value_get_int64 (value));
		break;
		case TUBA_API_ACCOUNT_STATUSES_COUNT_PROPERTY:
		tuba_api_account_set_statuses_count (self, g_value_get_int64 (value));
		break;
		case TUBA_API_ACCOUNT_LAST_STATUS_AT_PROPERTY:
		tuba_api_account_set_last_status_at (self, g_value_get_string (value));
		break;
		case TUBA_API_ACCOUNT_ROLES_PROPERTY:
		tuba_api_account_set_roles (self, g_value_get_object (value));
		break;
		case TUBA_API_ACCOUNT_FIELDS_PROPERTY:
		tuba_api_account_set_fields (self, g_value_get_object (value));
		break;
		case TUBA_API_ACCOUNT_SOURCE_PROPERTY:
		tuba_api_account_set_source (self, g_value_get_object (value));
		break;
		case TUBA_API_ACCOUNT_ROLE_PROPERTY:
		tuba_api_account_set_role (self, g_value_get_object (value));
		break;
		case TUBA_API_ACCOUNT_MOVED_PROPERTY:
		tuba_api_account_set_moved (self, g_value_get_object (value));
		break;
		case TUBA_API_ACCOUNT_HIDE_COLLECTIONS_PROPERTY:
		tuba_api_account_set_hide_collections (self, g_value_get_boolean (value));
		break;
		case TUBA_API_ACCOUNT_FEATURE_APPROVAL_PROPERTY:
		tuba_api_account_set_feature_approval (self, g_value_get_object (value));
		break;
		default:
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
		break;
	}
}

